@@ -17,6 +17,23 @@
 
 package org.apache.zeppelin.elasticsearch;
 
+import com.google.gson.Gson;
+import com.google.gson.GsonBuilder;
+import com.google.gson.JsonObject;
+
+import org.apache.commons.lang3.StringUtils;
+import org.elasticsearch.common.xcontent.XContentBuilder;
+import org.elasticsearch.common.xcontent.XContentFactory;
+import org.elasticsearch.common.xcontent.XContentHelper;
+import org.elasticsearch.search.aggregations.Aggregation;
+import org.elasticsearch.search.aggregations.Aggregations;
+import org.elasticsearch.search.aggregations.InternalMultiBucketAggregation;
+import org.elasticsearch.search.aggregations.bucket.InternalSingleBucketAggregation;
+import org.elasticsearch.search.aggregations.bucket.MultiBucketsAggregation;
+import org.elasticsearch.search.aggregations.metrics.InternalMetricsAggregation;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -32,7 +49,8 @@ import java.util.TreeSet;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import org.apache.commons.lang3.StringUtils;
+import com.github.wnameless.json.flattener.JsonFlattener;
+
 import org.apache.zeppelin.completer.CompletionType;
 import org.apache.zeppelin.elasticsearch.action.ActionResponse;
 import org.apache.zeppelin.elasticsearch.action.AggWrapper;
@@ -44,29 +62,11 @@ import org.apache.zeppelin.interpreter.Interpreter;
 import org.apache.zeppelin.interpreter.InterpreterContext;
 import org.apache.zeppelin.interpreter.InterpreterResult;
 import org.apache.zeppelin.interpreter.thrift.InterpreterCompletion;
-import org.elasticsearch.common.xcontent.XContentBuilder;
-import org.elasticsearch.common.xcontent.XContentFactory;
-import org.elasticsearch.common.xcontent.XContentHelper;
-import org.elasticsearch.search.aggregations.Aggregation;
-import org.elasticsearch.search.aggregations.Aggregations;
-import org.elasticsearch.search.aggregations.InternalMultiBucketAggregation;
-import org.elasticsearch.search.aggregations.bucket.InternalSingleBucketAggregation;
-import org.elasticsearch.search.aggregations.bucket.MultiBucketsAggregation;
-import org.elasticsearch.search.aggregations.metrics.InternalMetricsAggregation;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
-import com.github.wnameless.json.flattener.JsonFlattener;
-import com.google.gson.Gson;
-import com.google.gson.GsonBuilder;
-import com.google.gson.JsonObject;
-
 
 /**
  * Elasticsearch Interpreter for Zeppelin.
  */
 public class ElasticsearchInterpreter extends Interpreter {
-
   private static Logger logger = LoggerFactory.getLogger(ElasticsearchInterpreter.class);
 
   private static final String HELP = "Elasticsearch interpreter:\n"
@@ -92,7 +92,6 @@ public class ElasticsearchInterpreter extends Interpreter {
 
   private static final Pattern FIELD_NAME_PATTERN = Pattern.compile("\\[\\\\\"(.+)\\\\\"\\](.*)");
 
-
   public static final String ELASTICSEARCH_HOST = "elasticsearch.host";
   public static final String ELASTICSEARCH_PORT = "elasticsearch.port";
   public static final String ELASTICSEARCH_CLIENT_TYPE = "elasticsearch.client.type";
@@ -107,7 +106,6 @@ public class ElasticsearchInterpreter extends Interpreter {
 
   public ElasticsearchInterpreter(Properties property) {
     super(property);
-
   }
 
   @Override
@@ -119,8 +117,7 @@ public class ElasticsearchInterpreter extends Interpreter {
 
     try {
       this.resultSize = Integer.parseInt(getProperty(ELASTICSEARCH_RESULT_SIZE));
-    }
-    catch (final NumberFormatException e) {
+    } catch (final NumberFormatException e) {
       this.resultSize = 10;
       logger.error("Unable to parse " + ELASTICSEARCH_RESULT_SIZE + " : " +
           getProperty(ELASTICSEARCH_RESULT_SIZE), e);
@@ -129,15 +126,12 @@ public class ElasticsearchInterpreter extends Interpreter {
     try {
       if (StringUtils.isEmpty(clientType) || "transport".equals(clientType)) {
         elsClient = new TransportBasedClient(getProperties());
-      }
-      else if ("http".equals(clientType)) {
+      } else if ("http".equals(clientType)) {
         elsClient = new HttpBasedClient(getProperties());
-      }
-      else {
+      } else {
         logger.error("Unknown type of Elasticsearch client: " + clientType);
       }
-    }
-    catch (final IOException e) {
+    } catch (final IOException e) {
       logger.error("Open connection with Elasticsearch", e);
     }
   }
@@ -203,23 +197,18 @@ public class ElasticsearchInterpreter extends Interpreter {
     try {
       if ("get".equalsIgnoreCase(method)) {
         return processGet(urlItems, interpreterContext);
-      }
-      else if ("count".equalsIgnoreCase(method)) {
+      } else if ("count".equalsIgnoreCase(method)) {
         return processCount(urlItems, data, interpreterContext);
-      }
-      else if ("search".equalsIgnoreCase(method)) {
+      } else if ("search".equalsIgnoreCase(method)) {
         return processSearch(urlItems, data, currentResultSize, interpreterContext);
-      }
-      else if ("index".equalsIgnoreCase(method)) {
+      } else if ("index".equalsIgnoreCase(method)) {
         return processIndex(urlItems, data);
-      }
-      else if ("delete".equalsIgnoreCase(method)) {
+      } else if ("delete".equalsIgnoreCase(method)) {
         return processDelete(urlItems);
       }
 
       return processHelp(InterpreterResult.Code.ERROR, "Unknown command");
-    }
-    catch (final Exception e) {
+    } catch (final Exception e) {
       return new InterpreterResult(InterpreterResult.Code.ERROR, "Error : " + e.getMessage());
     }
   }
@@ -259,7 +248,6 @@ public class ElasticsearchInterpreter extends Interpreter {
   }
 
   private String[] getIndexTypeId(String[] urlItems) {
-
     if (urlItems.length < 3) {
       return null;
     }
@@ -279,7 +267,6 @@ public class ElasticsearchInterpreter extends Interpreter {
 
   private InterpreterResult processHelp(InterpreterResult.Code code, String additionalMessage) {
     final StringBuffer buffer = new StringBuffer();
-
     if (additionalMessage != null) {
       buffer.append(additionalMessage).append("\n");
     }
@@ -297,7 +284,6 @@ public class ElasticsearchInterpreter extends Interpreter {
    * @return Result of the get request, it contains a JSON-formatted string
    */
   private InterpreterResult processGet(String[] urlItems, InterpreterContext interpreterContext) {
-
     final String[] indexTypeId = getIndexTypeId(urlItems);
 
     if (indexTypeId == null) {
@@ -332,7 +318,6 @@ public class ElasticsearchInterpreter extends Interpreter {
    */
   private InterpreterResult processCount(String[] urlItems, String data,
       InterpreterContext interpreterContext) {
-
     if (urlItems.length > 2) {
       return new InterpreterResult(InterpreterResult.Code.ERROR,
           "Bad URL (it should be /index1,index2,.../type1,type2,...)");
@@ -359,7 +344,6 @@ public class ElasticsearchInterpreter extends Interpreter {
    */
   private InterpreterResult processSearch(String[] urlItems, String data, int size,
       InterpreterContext interpreterContext) {
-
     if (urlItems.length > 2) {
       return new InterpreterResult(InterpreterResult.Code.ERROR,
           "Bad URL (it should be /index1,index2,.../type1,type2,...)");
@@ -382,7 +366,6 @@ public class ElasticsearchInterpreter extends Interpreter {
    * @return Result of the index request, it contains the id of the document
    */
   private InterpreterResult processIndex(String[] urlItems, String data) {
-
     if (urlItems.length < 2 || urlItems.length > 3) {
       return new InterpreterResult(InterpreterResult.Code.ERROR,
           "Bad URL (it should be /index/type or /index/type/id)");
@@ -404,7 +387,6 @@ public class ElasticsearchInterpreter extends Interpreter {
    * @return Result of the delete request, it contains the id of the deleted document
    */
   private InterpreterResult processDelete(String[] urlItems) {
-
     final String[] indexTypeId = getIndexTypeId(urlItems);
 
     if (indexTypeId == null) {
@@ -426,7 +408,6 @@ public class ElasticsearchInterpreter extends Interpreter {
   }
 
   private ActionResponse searchData(String[] urlItems, String query, int size) {
-
     String[] indices = null;
     String[] types = null;
 
@@ -441,7 +422,6 @@ public class ElasticsearchInterpreter extends Interpreter {
   }
 
   private InterpreterResult buildAggResponseMessage(Aggregations aggregations) {
-
     // Only the result of the first aggregation is returned
     //
     final Aggregation agg = aggregations.asList().get(0);
@@ -450,11 +430,9 @@ public class ElasticsearchInterpreter extends Interpreter {
 
     if (agg instanceof InternalMetricsAggregation) {
       resMsg = XContentHelper.toString((InternalMetricsAggregation) agg).toString();
-    }
-    else if (agg instanceof InternalSingleBucketAggregation) {
+    } else if (agg instanceof InternalSingleBucketAggregation) {
       resMsg = XContentHelper.toString((InternalSingleBucketAggregation) agg).toString();
-    }
-    else if (agg instanceof InternalMultiBucketAggregation) {
+    } else if (agg instanceof InternalMultiBucketAggregation) {
       final Set<String> headerKeys = new HashSet<>();
       final List<Map<String, Object>> buckets = new LinkedList<>();
       final InternalMultiBucketAggregation multiBucketAgg = (InternalMultiBucketAggregation) agg;
@@ -466,8 +444,7 @@ public class ElasticsearchInterpreter extends Interpreter {
           final Map<String, Object> bucketMap = JsonFlattener.flattenAsMap(builder.string());
           headerKeys.addAll(bucketMap.keySet());
           buckets.add(bucketMap);
-        }
-        catch (final IOException e) {
+        } catch (final IOException e) {
           logger.error("Processing bucket: " + e.getMessage(), e);
         }
       }
@@ -496,7 +473,6 @@ public class ElasticsearchInterpreter extends Interpreter {
   }
 
   private InterpreterResult buildAggResponseMessage(List<AggWrapper> aggregations) {
-
     final InterpreterResult.Type resType = InterpreterResult.Type.TABLE;
     String resMsg = "";
 
@@ -531,7 +507,6 @@ public class ElasticsearchInterpreter extends Interpreter {
   }
 
   private String buildSearchHitsResponseMessage(ActionResponse response) {
-
     if (response.getHits() == null || response.getHits().size() == 0) {
       return "";
     }
@@ -553,8 +528,7 @@ public class ElasticsearchInterpreter extends Interpreter {
         if (fieldNameMatcher.matches()) {
           flattenMap.put(fieldNameMatcher.group(1) + fieldNameMatcher.group(2),
               flattenJsonMap.get(fieldName));
-        }
-        else {
+        } else {
           flattenMap.put(fieldName, flattenJsonMap.get(fieldName));
         }
       }
@@ -590,7 +564,6 @@ public class ElasticsearchInterpreter extends Interpreter {
   }
 
   private InterpreterResult buildResponseMessage(ActionResponse response) {
-
     final List<AggWrapper> aggregations = response.getAggregations();
 
     if (aggregations != null && aggregations.size() > 0) {
