@@ -18,7 +18,6 @@
 
 package org.apache.zeppelin.flink;
 
-import com.google.common.collect.Lists;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.exception.ExceptionUtils;
@@ -43,6 +42,7 @@ import org.slf4j.LoggerFactory;
 import javax.annotation.Nullable;
 import java.io.FileInputStream;
 import java.io.IOException;
+import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
@@ -61,7 +61,7 @@ public abstract class FlinkSqlInterpreter extends AbstractInterpreter {
   private int defaultSqlParallelism;
   private ReentrantReadWriteLock.WriteLock lock = new ReentrantReadWriteLock().writeLock();
   // all the available sql config options. see
-  // https://ci.apache.org/projects/flink/flink-docs-release-1.10/dev/table/config.html
+  // https://ci.apache.org/projects/flink/flink-docs-master/docs/dev/table/config/
   private Map<String, ConfigOption> tableConfigOptions;
 
   public FlinkSqlInterpreter(Properties properties) {
@@ -430,7 +430,7 @@ public abstract class FlinkSqlInterpreter extends AbstractInterpreter {
 
   private void callShowTables(InterpreterContext context) throws IOException {
     List<String> tables =
-            Lists.newArrayList(this.tbenv.listTables()).stream()
+            Arrays.asList(this.tbenv.listTables()).stream()
                     .filter(tbl -> !tbl.startsWith("UnnamedTable")).collect(Collectors.toList());
     context.out.write(
             "%table table\n" + StringUtils.join(tables, "\n") + "\n");
@@ -523,7 +523,7 @@ public abstract class FlinkSqlInterpreter extends AbstractInterpreter {
 
     if (!tableConfigOptions.containsKey(key)) {
       throw new IOException(key + " is not a valid table/sql config, please check link: " +
-              "https://ci.apache.org/projects/flink/flink-docs-release-1.10/dev/table/config.html");
+              "https://ci.apache.org/projects/flink/flink-docs-master/docs/dev/table/config/");
     }
 
     LOGGER.info("Set table config: {}={}", key, value);
