@@ -18,7 +18,7 @@
 
 package org.apache.zeppelin.flink
 
-import java.io.File
+import java.io.{File, IOException}
 import java.net.{URL, URLClassLoader}
 import java.nio.file.Files
 import java.util.Properties
@@ -45,6 +45,7 @@ import org.apache.flink.table.functions.{AggregateFunction, ScalarFunction, Tabl
 import org.apache.flink.table.module.hive.HiveModule
 import org.apache.flink.yarn.cli.FlinkYarnSessionCli
 import org.apache.zeppelin.dep.DependencyResolver
+import org.apache.zeppelin.flink.internal.FlinkShell
 import org.apache.zeppelin.flink.internal.FlinkShell._
 import org.apache.zeppelin.flink.internal.FlinkILoop
 import org.apache.zeppelin.interpreter.Interpreter.FormType
@@ -145,7 +146,7 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
     // load udf jar
     this.userUdfJars.foreach(jar => loadUDFJar(jar))
 
-    if (mode == ExecutionMode.YARN_APPLICATION) {
+    if (ExecutionMode.isApplicationMode(mode)) {
       // have to call senv.execute method before running any user code, otherwise yarn application mode
       // will cause ClassNotFound issue. Needs to do more investigation. TODO(zjffdu)
       val initCode =
@@ -185,7 +186,7 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
       properties.getProperty("flink.execution.mode", "LOCAL")
         .replace("-", "_")
         .toUpperCase)
-    if (mode == ExecutionMode.YARN_APPLICATION) {
+    if (ExecutionMode.isYarnAppicationMode(mode)) {
       if (flinkVersion.isFlink110) {
         throw new Exception("yarn-application mode is only supported after Flink 1.11")
       }
@@ -195,6 +196,17 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
       flinkConfDir = workingDirectory
       hiveConfDir = workingDirectory
     }
+    if (ExecutionMode.isK8sApplicationMode(mode)) {
+      if (flinkVersion.isFlink110) {
+        throw new Exception("application mode is only supported after Flink 1.11")
+      }
+      // use current pod working directory as FLINK_HOME
+      val workingDirectory = new File(".").getAbsolutePath
+      flinkHome = workingDirectory
+      flinkConfDir = workingDirectory + "/conf"
+      hiveConfDir = workingDirectory + "/conf"
+    }
+
     LOGGER.info("FLINK_HOME: " + flinkHome)
     LOGGER.info("FLINK_CONF_DIR: " + flinkConfDir)
     LOGGER.info("HADOOP_CONF_DIR: " + hadoopConfDir)
@@ -234,7 +246,17 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
         .copy(queue = Some(queue))))
 
     this.userUdfJars = getUserUdfJars()
+
     this.userJars = getUserJarsExceptUdfJars ++ this.userUdfJars
+    if (ExecutionMode.isK8sApplicationMode(mode)) {
+      var flinkAppJar = properties.getProperty("flink.app.jar")
+      if (flinkAppJar != null && flinkAppJar.startsWith("local://")) {
+        flinkAppJar = flinkAppJar.substring(8)
+        this.userJars = this.userJars :+ flinkAppJar
+      } else {
+        throw new IOException("flink.app.jar is not set or invalid, flink.app.jar: " + flinkAppJar)
+      }
+    }
     LOGGER.info("UserJars: " + userJars.mkString(","))
     config = config.copy(externalJars = Some(userJars.toArray))
     LOGGER.info("Config: " + config)
@@ -317,6 +339,10 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
             LOGGER.info("Use FlinkCluster in yarn application mode, appId: {}", yarnAppId)
             this.jmWebUrl = "http://localhost:" + HadoopUtils.getFlinkRestPort(yarnAppId)
             this.displayedJMWebUrl = getDisplayedJMWebUrl(yarnAppId)
+          } else if (ExecutionMode.isK8sApplicationMode(mode)) {
+            LOGGER.info("Use FlinkCluster in kubernetes-application mode")
+            this.jmWebUrl = "http://localhost:" + configuration.getInteger("rest.port", 8081)
+            this.displayedJMWebUrl = this.jmWebUrl
           } else {
             LOGGER.info("Use FlinkCluster in remote mode")
             this.jmWebUrl = "http://" + config.host.get + ":" + config.port.get
@@ -447,17 +473,19 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
       flinkILoop.bind("stenv", stenv.getClass().getCanonicalName(), stenv, List("@transient"))
       this.java_stenv = tblEnvFactory.createJavaBlinkStreamTableEnvironment(stEnvSetting, getFlinkClassLoader)
 
-      // flink planner
-      this.btenv_2 = tblEnvFactory.createScalaFlinkBatchTableEnvironment()
-      flinkILoop.bind("btenv_2", btenv_2.getClass().getCanonicalName(), btenv_2, List("@transient"))
-      stEnvSetting =
-        EnvironmentSettings.newInstance().inStreamingMode().useOldPlanner().build()
-      this.stenv_2 = tblEnvFactory.createScalaFlinkStreamTableEnvironment(stEnvSetting, getFlinkClassLoader)
-      flinkILoop.bind("stenv_2", stenv_2.getClass().getCanonicalName(), stenv_2, List("@transient"))
+      if (!flinkVersion.isAfterFlink114()) {
+        // flink planner is not supported after flink 1.14
+        this.btenv_2 = tblEnvFactory.createScalaFlinkBatchTableEnvironment()
+        flinkILoop.bind("btenv_2", btenv_2.getClass().getCanonicalName(), btenv_2, List("@transient"))
+        stEnvSetting =
+          EnvironmentSettings.newInstance().inStreamingMode().useOldPlanner().build()
+        this.stenv_2 = tblEnvFactory.createScalaFlinkStreamTableEnvironment(stEnvSetting, getFlinkClassLoader)
+        flinkILoop.bind("stenv_2", stenv_2.getClass().getCanonicalName(), stenv_2, List("@transient"))
 
-      this.java_btenv_2 = tblEnvFactory.createJavaFlinkBatchTableEnvironment()
-      btEnvSetting = EnvironmentSettings.newInstance.useOldPlanner.inStreamingMode.build
-      this.java_stenv_2 = tblEnvFactory.createJavaFlinkStreamTableEnvironment(btEnvSetting, getFlinkClassLoader)
+        this.java_btenv_2 = tblEnvFactory.createJavaFlinkBatchTableEnvironment()
+        btEnvSetting = EnvironmentSettings.newInstance.useOldPlanner.inStreamingMode.build
+        this.java_stenv_2 = tblEnvFactory.createJavaFlinkStreamTableEnvironment(btEnvSetting, getFlinkClassLoader)
+      }
     } finally {
       Thread.currentThread().setContextClassLoader(originalClassLoader)
     }
@@ -489,13 +517,13 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
 
   private def registerHiveCatalog(): Unit = {
     val hiveConfDir =
-      properties.getOrDefault("HIVE_CONF_DIR", System.getenv("HIVE_CONF_DIR")).toString
+      properties.getOrDefault("HIVE_CONF_DIR", System.getenv("HIVE_CONF_DIR"))
     if (hiveConfDir == null) {
       throw new InterpreterException("HIVE_CONF_DIR is not specified");
     }
     val database = properties.getProperty("zeppelin.flink.hive.database", "default")
     val hiveVersion = properties.getProperty("zeppelin.flink.hive.version", "2.3.4")
-    val hiveCatalog = new HiveCatalog("hive", database, hiveConfDir, hiveVersion)
+    val hiveCatalog = new HiveCatalog("hive", database, hiveConfDir.toString, hiveVersion)
     this.btenv.registerCatalog("hive", hiveCatalog)
     this.btenv.useCatalog("hive")
     this.btenv.useDatabase(database)
@@ -919,8 +947,8 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
   def completion(buf: String, cursor: Int, context: InterpreterContext): java.util.List[InterpreterCompletion]
 
   private def getConfigurationOfStreamExecutionEnv(): Configuration = {
-    val getConfigurationMethod = classOf[JStreamExecutionEnvironment].getDeclaredMethod("getConfiguration")
-    getConfigurationMethod.setAccessible(true)
-    getConfigurationMethod.invoke(this.senv.getJavaEnv).asInstanceOf[Configuration]
+    val configurationField = classOf[JStreamExecutionEnvironment].getDeclaredField("configuration")
+    configurationField.setAccessible(true)
+    configurationField.get(this.senv.getJavaEnv).asInstanceOf[Configuration]
   }
 }
