@@ -17,26 +17,12 @@
 
 package org.apache.zeppelin.livy;
 
-import java.io.FileInputStream;
-import java.io.IOException;
-import java.nio.charset.Charset;
-import java.security.KeyStore;
-import java.security.Principal;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Properties;
-import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
+import com.google.gson.Gson;
+import com.google.gson.GsonBuilder;
+import com.google.gson.annotations.SerializedName;
 
-import javax.net.ssl.SSLContext;
-
-import org.apache.commons.lang.StringUtils;
-import org.apache.commons.lang.exception.ExceptionUtils;
+import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.exception.ExceptionUtils;
 import org.apache.http.auth.AuthSchemeProvider;
 import org.apache.http.auth.AuthScope;
 import org.apache.http.auth.Credentials;
@@ -48,20 +34,11 @@ import org.apache.http.config.Registry;
 import org.apache.http.config.RegistryBuilder;
 import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
 import org.apache.http.conn.ssl.SSLContexts;
+import org.apache.http.conn.ssl.SSLContextBuilder;
 import org.apache.http.impl.auth.SPNegoSchemeFactory;
 import org.apache.http.impl.client.BasicCredentialsProvider;
 import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.impl.client.HttpClients;
-import org.apache.zeppelin.interpreter.Interpreter;
-import org.apache.zeppelin.interpreter.Interpreter.FormType;
-import org.apache.zeppelin.interpreter.InterpreterContext;
-import org.apache.zeppelin.interpreter.InterpreterException;
-import org.apache.zeppelin.interpreter.InterpreterResult;
-import org.apache.zeppelin.interpreter.InterpreterResultMessage;
-import org.apache.zeppelin.interpreter.InterpreterUtils;
-import org.apache.zeppelin.interpreter.LazyOpenInterpreter;
-import org.apache.zeppelin.interpreter.WrappedInterpreter;
-import org.apache.zeppelin.interpreter.thrift.InterpreterCompletion;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.http.HttpEntity;
@@ -77,10 +54,30 @@ import org.springframework.web.client.HttpServerErrorException;
 import org.springframework.web.client.RestClientException;
 import org.springframework.web.client.RestTemplate;
 
-import com.google.gson.Gson;
-import com.google.gson.GsonBuilder;
-import com.google.gson.annotations.SerializedName;
+import java.io.FileInputStream;
+import java.nio.charset.StandardCharsets;
+import java.security.KeyStore;
+import java.security.Principal;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Properties;
+import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
+import javax.net.ssl.SSLContext;
+
+import org.apache.zeppelin.interpreter.Interpreter;
+import org.apache.zeppelin.interpreter.InterpreterContext;
+import org.apache.zeppelin.interpreter.InterpreterException;
+import org.apache.zeppelin.interpreter.InterpreterResult;
+import org.apache.zeppelin.interpreter.InterpreterResultMessage;
+import org.apache.zeppelin.interpreter.InterpreterUtils;
+import org.apache.zeppelin.interpreter.thrift.InterpreterCompletion;
 
 /**
  * Base class for livy interpreters.
@@ -160,7 +157,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
     try {
       this.livyVersion = getLivyVersion();
       if (this.livyVersion.isSharedSupported()) {
-        sharedInterpreter = getLivySharedInterpreter();
+        sharedInterpreter = getInterpreterInTheSameSessionByClassName(LivySharedInterpreter.class);
       }
       if (sharedInterpreter == null || !sharedInterpreter.isSupported()) {
         initLivySession();
@@ -172,26 +169,6 @@ public abstract class BaseLivyInterpreter extends Interpreter {
     }
   }
 
-  protected LivySharedInterpreter getLivySharedInterpreter() throws InterpreterException {
-    LazyOpenInterpreter lazy = null;
-    LivySharedInterpreter sharedInterpreter = null;
-    Interpreter p = getInterpreterInTheSameSessionByClassName(
-        LivySharedInterpreter.class.getName());
-
-    while (p instanceof WrappedInterpreter) {
-      if (p instanceof LazyOpenInterpreter) {
-        lazy = (LazyOpenInterpreter) p;
-      }
-      p = ((WrappedInterpreter) p).getInnerInterpreter();
-    }
-    sharedInterpreter = (LivySharedInterpreter) p;
-
-    if (lazy != null) {
-      lazy.open();
-    }
-    return sharedInterpreter;
-  }
-
   @Override
   public void close() {
     if (sharedInterpreter != null && sharedInterpreter.isSupported()) {
@@ -257,7 +234,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
     try {
       return interpret(st, null, context.getParagraphId(), this.displayAppInfo, true, true);
     } catch (LivyException e) {
-      LOGGER.error("Fail to interpret:" + st, e);
+      LOGGER.error("Fail to interpret: {}", st, e);
       return new InterpreterResult(InterpreterResult.Code.ERROR,
           InterpreterUtils.getMostRelevantMessage(e));
     }
@@ -273,7 +250,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
       LOGGER.warn("Livy session {} is expired. Will return empty list of candidates.",
           getSessionInfo().id);
     } catch (LivyException le) {
-      logger.error("Failed to call code completions. Will return empty list of candidates", le);
+      LOGGER.error("Failed to call code completions. Will return empty list of candidates", le);
     }
     return candidates;
   }
@@ -287,7 +264,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
         candidates.add(new InterpreterCompletion(candidate, candidate, StringUtils.EMPTY));
       }
     } catch (APINotFoundException e) {
-      logger.debug("completion api seems not to be available. (available from livy 0.5)", e);
+      LOGGER.debug("completion api seems not to be available. (available from livy 0.5)", e);
     }
     return candidates;
   }
@@ -299,7 +276,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
       return;
     }
     paragraphsToCancel.add(context.getParagraphId());
-    LOGGER.info("Added paragraph " + context.getParagraphId() + " for cancellation.");
+    LOGGER.info("Added paragraph {} for cancellation.", context.getParagraphId());
   }
 
   @Override
@@ -327,8 +304,9 @@ public abstract class BaseLivyInterpreter extends Interpreter {
       Map<String, String> conf = new HashMap<>();
       for (Map.Entry<Object, Object> entry : getProperties().entrySet()) {
         if (entry.getKey().toString().startsWith("livy.spark.") &&
-            !entry.getValue().toString().isEmpty())
+            !entry.getValue().toString().isEmpty()) {
           conf.put(entry.getKey().toString().substring(5), entry.getValue().toString());
+        }
       }
 
       CreateSessionRequest request = new CreateSessionRequest(kind,
@@ -356,7 +334,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
       }
       return sessionInfo;
     } catch (Exception e) {
-      LOGGER.error("Error when creating livy session for user " + user, e);
+      LOGGER.error("Error when creating livy session for user {}", user, e);
       throw new LivyException(e);
     }
   }
@@ -454,16 +432,15 @@ public abstract class BaseLivyInterpreter extends Interpreter {
   private void cancel(int id, String paragraphId) {
     if (livyVersion.isCancelSupported()) {
       try {
-        LOGGER.info("Cancelling statement " + id);
+        LOGGER.info("Cancelling statement {}", id);
         cancelStatement(id);
       } catch (LivyException e) {
-        LOGGER.error("Fail to cancel statement " + id + " for paragraph " + paragraphId, e);
-      }
-      finally {
+        LOGGER.error("Fail to cancel statement {} for paragraph {}", id, paragraphId, e);
+      } finally {
         paragraphsToCancel.remove(paragraphId);
       }
     } else {
-      LOGGER.warn("cancel is not supported for this version of livy: " + livyVersion);
+      LOGGER.warn("cancel is not supported for this version of livy: {}", livyVersion);
       paragraphsToCancel.clear();
     }
   }
@@ -512,8 +489,10 @@ public abstract class BaseLivyInterpreter extends Interpreter {
       StringBuilder sb = new StringBuilder();
       sb.append(stmtInfo.output.evalue);
       // in case evalue doesn't have newline char
-      if (!stmtInfo.output.evalue.contains("\n"))
+      if (!stmtInfo.output.evalue.contains("\n")) {
         sb.append("\n");
+      }
+
       if (stmtInfo.output.traceback != null) {
         sb.append(StringUtils.join(stmtInfo.output.traceback));
       }
@@ -527,14 +506,14 @@ public abstract class BaseLivyInterpreter extends Interpreter {
       return new InterpreterResult(InterpreterResult.Code.ERROR, "Empty output");
     } else {
       //TODO(zjffdu) support other types of data (like json, image and etc)
-      String result = stmtInfo.output.data.plain_text;
+      String result = stmtInfo.output.data.plainText;
 
       // check table magic result first
-      if (stmtInfo.output.data.application_livy_table_json != null) {
+      if (stmtInfo.output.data.applicationLivyTableJson != null) {
         StringBuilder outputBuilder = new StringBuilder();
         boolean notFirstColumn = false;
 
-        for (Map header : stmtInfo.output.data.application_livy_table_json.headers) {
+        for (Map header : stmtInfo.output.data.applicationLivyTableJson.headers) {
           if (notFirstColumn) {
             outputBuilder.append("\t");
           }
@@ -543,15 +522,15 @@ public abstract class BaseLivyInterpreter extends Interpreter {
         }
 
         outputBuilder.append("\n");
-        for (List<Object> row : stmtInfo.output.data.application_livy_table_json.records) {
+        for (List<Object> row : stmtInfo.output.data.applicationLivyTableJson.records) {
           outputBuilder.append(StringUtils.join(row, "\t"));
           outputBuilder.append("\n");
         }
         return new InterpreterResult(InterpreterResult.Code.SUCCESS,
             InterpreterResult.Type.TABLE, outputBuilder.toString());
-      } else if (stmtInfo.output.data.image_png != null) {
+      } else if (stmtInfo.output.data.imagePng != null) {
         return new InterpreterResult(InterpreterResult.Code.SUCCESS,
-            InterpreterResult.Type.IMG, (String) stmtInfo.output.data.image_png);
+            InterpreterResult.Type.IMG, stmtInfo.output.data.imagePng);
       } else if (result != null) {
         result = result.trim();
         if (result.startsWith("<link")
@@ -592,6 +571,49 @@ public abstract class BaseLivyInterpreter extends Interpreter {
     callRestAPI("/sessions/" + sessionInfo.id + "/statements/" + statementId + "/cancel", "POST");
   }
 
+  private SSLContext getSslContext() {
+    try {
+      // Build truststore
+      String trustStoreFile = getProperty("zeppelin.livy.ssl.trustStore");
+      String trustStorePassword = getProperty("zeppelin.livy.ssl.trustStorePassword");
+      String trustStoreType = getProperty("zeppelin.livy.ssl.trustStoreType",
+              KeyStore.getDefaultType());
+      if (StringUtils.isBlank(trustStoreFile)) {
+        throw new RuntimeException("No zeppelin.livy.ssl.trustStore specified for livy ssl");
+      }
+      if (StringUtils.isBlank(trustStorePassword)) {
+        throw new RuntimeException("No zeppelin.livy.ssl.trustStorePassword specified " +
+                "for livy ssl");
+      }
+      KeyStore trustStore = getStore(trustStoreFile, trustStoreType, trustStorePassword);
+      SSLContextBuilder builder = SSLContexts.custom();
+      builder.loadTrustMaterial(trustStore);
+
+      // Build keystore
+      String keyStoreFile = getProperty("zeppelin.livy.ssl.keyStore");
+      String keyStorePassword = getProperty("zeppelin.livy.ssl.keyStorePassword");
+      String keyPassword = getProperty("zeppelin.livy.ssl.keyPassword", keyStorePassword);
+      String keyStoreType = getProperty("zeppelin.livy.ssl.keyStoreType",
+              KeyStore.getDefaultType());
+      if (StringUtils.isNotBlank(keyStoreFile)) {
+        KeyStore keyStore = getStore(keyStoreFile, keyStoreType, keyStorePassword);
+        builder.loadKeyMaterial(keyStore, keyPassword.toCharArray()).useTLS();
+      }
+      return builder.build();
+    } catch (Exception e) {
+      throw new RuntimeException("Failed to create SSL Context", e);
+    }
+  }
+
+  private KeyStore getStore(String file, String type, String password) {
+    try (FileInputStream inputStream = new FileInputStream(file)) {
+      KeyStore trustStore = KeyStore.getInstance(type);
+      trustStore.load(inputStream, password.toCharArray());
+      return trustStore;
+    } catch (Exception e) {
+      throw new RuntimeException("Failed to open keystore " + file, e);
+    }
+  }
 
   private RestTemplate createRestTemplate() {
     String keytabLocation = getProperty("zeppelin.livy.keytab");
@@ -601,47 +623,32 @@ public abstract class BaseLivyInterpreter extends Interpreter {
 
     HttpClient httpClient = null;
     if (livyURL.startsWith("https:")) {
-      String keystoreFile = getProperty("zeppelin.livy.ssl.trustStore");
-      String password = getProperty("zeppelin.livy.ssl.trustStorePassword");
-      if (StringUtils.isBlank(keystoreFile)) {
-        throw new RuntimeException("No zeppelin.livy.ssl.trustStore specified for livy ssl");
-      }
-      if (StringUtils.isBlank(password)) {
-        throw new RuntimeException("No zeppelin.livy.ssl.trustStorePassword specified " +
-            "for livy ssl");
-      }
-      FileInputStream inputStream = null;
       try {
-        inputStream = new FileInputStream(keystoreFile);
-        KeyStore trustStore = KeyStore.getInstance(KeyStore.getDefaultType());
-        trustStore.load(new FileInputStream(keystoreFile), password.toCharArray());
-        SSLContext sslContext = SSLContexts.custom()
-            .loadTrustMaterial(trustStore)
-            .build();
+        SSLContext sslContext = getSslContext();
         SSLConnectionSocketFactory csf = new SSLConnectionSocketFactory(sslContext);
         HttpClientBuilder httpClientBuilder = HttpClients.custom().setSSLSocketFactory(csf);
-        RequestConfig reqConfig = new RequestConfig() {
-          @Override
-          public boolean isAuthenticationEnabled() {
-            return true;
-          }
-        };
-        httpClientBuilder.setDefaultRequestConfig(reqConfig);
-        Credentials credentials = new Credentials() {
-          @Override
-          public String getPassword() {
-            return null;
-          }
-
-          @Override
-          public Principal getUserPrincipal() {
-            return null;
-          }
-        };
-        CredentialsProvider credsProvider = new BasicCredentialsProvider();
-        credsProvider.setCredentials(AuthScope.ANY, credentials);
-        httpClientBuilder.setDefaultCredentialsProvider(credsProvider);
         if (isSpnegoEnabled) {
+          RequestConfig reqConfig = new RequestConfig() {
+            @Override
+            public boolean isAuthenticationEnabled() {
+              return true;
+            }
+          };
+          httpClientBuilder.setDefaultRequestConfig(reqConfig);
+          Credentials credentials = new Credentials() {
+            @Override
+            public String getPassword() {
+              return null;
+            }
+
+            @Override
+            public Principal getUserPrincipal() {
+              return null;
+            }
+          };
+          CredentialsProvider credsProvider = new BasicCredentialsProvider();
+          credsProvider.setCredentials(AuthScope.ANY, credentials);
+          httpClientBuilder.setDefaultCredentialsProvider(credsProvider);
           Registry<AuthSchemeProvider> authSchemeProviderRegistry =
               RegistryBuilder.<AuthSchemeProvider>create()
                   .register(AuthSchemes.SPNEGO, new SPNegoSchemeFactory())
@@ -652,18 +659,10 @@ public abstract class BaseLivyInterpreter extends Interpreter {
         httpClient = httpClientBuilder.build();
       } catch (Exception e) {
         throw new RuntimeException("Failed to create SSL HttpClient", e);
-      } finally {
-        if (inputStream != null) {
-          try {
-            inputStream.close();
-          } catch (IOException e) {
-            LOGGER.error("Failed to close keystore file", e);
-          }
-        }
       }
     }
 
-    RestTemplate restTemplate = null;
+    RestTemplate restTemplate;
     if (isSpnegoEnabled) {
       if (httpClient == null) {
         restTemplate = new KerberosRestTemplate(keytabLocation, principal);
@@ -678,7 +677,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
       }
     }
     restTemplate.getMessageConverters().add(0,
-        new StringHttpMessageConverter(Charset.forName("UTF-8")));
+            new StringHttpMessageConverter(StandardCharsets.UTF_8));
     return restTemplate;
   }
 
@@ -720,7 +719,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
           throw new SessionNotFoundException(cause.getResponseBodyAsString());
         }
         throw new LivyException(cause.getResponseBodyAsString() + "\n"
-            + ExceptionUtils.getFullStackTrace(ExceptionUtils.getRootCause(e)));
+            + ExceptionUtils.getStackTrace(ExceptionUtils.getRootCause(e)));
       }
       if (e instanceof HttpServerErrorException) {
         HttpServerErrorException errorException = (HttpServerErrorException) e;
@@ -778,7 +777,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
     public final String user;
     public final Map<String, String> conf;
 
-    public CreateSessionRequest(String kind, String user, Map<String, String> conf) {
+    CreateSessionRequest(String kind, String user, Map<String, String> conf) {
       this.kind = kind;
       this.user = user;
       this.conf = conf;
@@ -846,7 +845,8 @@ public abstract class BaseLivyInterpreter extends Interpreter {
   static class ExecuteRequest {
     public final String code;
     public final String kind;
-    public ExecuteRequest(String code, String kind) {
+
+    ExecuteRequest(String code, String kind) {
       this.code = code;
       this.kind = kind;
     }
@@ -862,22 +862,22 @@ public abstract class BaseLivyInterpreter extends Interpreter {
     public double progress;
     public StatementOutput output;
 
-    public StatementInfo() {
+    StatementInfo() {
     }
 
     public static StatementInfo fromJson(String json) {
-      String right_json = "";
+      String rightJson = "";
       try {
         gson.fromJson(json, StatementInfo.class);
-        right_json = json;
+        rightJson = json;
       } catch (Exception e) {
         if (json.contains("\"traceback\":{}")) {
           LOGGER.debug("traceback type mismatch, replacing the mismatching part ");
-          right_json = json.replace("\"traceback\":{}", "\"traceback\":[]");
-          LOGGER.debug("new json string is {}", right_json);
+          rightJson = json.replace("\"traceback\":{}", "\"traceback\":[]");
+          LOGGER.debug("new json string is {}", rightJson);
         }
       }
-      return gson.fromJson(right_json, StatementInfo.class);
+      return gson.fromJson(rightJson, StatementInfo.class);
     }
 
     public boolean isAvailable() {
@@ -890,7 +890,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
 
     private static class StatementOutput {
       public String status;
-      public String execution_count;
+      public String executionCount;
       public Data data;
       public String ename;
       public String evalue;
@@ -907,13 +907,13 @@ public abstract class BaseLivyInterpreter extends Interpreter {
 
       private static class Data {
         @SerializedName("text/plain")
-        public String plain_text;
+        public String plainText;
         @SerializedName("image/png")
-        public String image_png;
+        public String imagePng;
         @SerializedName("application/json")
-        public String application_json;
+        public String applicationJson;
         @SerializedName("application/vnd.livy.table.v1+json")
-        public TableMagic application_livy_table_json;
+        public TableMagic applicationLivyTableJson;
       }
 
       private static class TableMagic {
@@ -931,7 +931,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
     public final String kind;
     public final int cursor;
 
-    public CompletionRequest(String code, String kind, int cursor) {
+    CompletionRequest(String code, String kind, int cursor) {
       this.code = code;
       this.kind = kind;
       this.cursor = cursor;
@@ -945,7 +945,7 @@ public abstract class BaseLivyInterpreter extends Interpreter {
   static class CompletionResponse {
     public final String[] candidates;
 
-    public CompletionResponse(String[] candidates) {
+    CompletionResponse(String[] candidates) {
       this.candidates = candidates;
     }
 
@@ -966,5 +966,4 @@ public abstract class BaseLivyInterpreter extends Interpreter {
       return gson.fromJson(json, LivyVersionResponse.class);
     }
   }
-
 }
