@@ -17,6 +17,20 @@
 
 package org.apache.zeppelin.livy;
 
+import com.google.gson.Gson;
+import com.google.gson.reflect.TypeToken;
+
+import java.io.IOException;
+import java.io.StringWriter;
+import java.io.Writer;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Properties;
+import java.util.Arrays;
+import java.util.Map;
+import java.util.Locale;
+
 import org.apache.commons.lang3.StringUtils;
 import org.apache.zeppelin.interpreter.InterpreterContext;
 import org.apache.zeppelin.interpreter.InterpreterException;
@@ -28,16 +42,12 @@ import org.apache.zeppelin.interpreter.ResultMessages;
 import org.apache.zeppelin.scheduler.Scheduler;
 import org.apache.zeppelin.scheduler.SchedulerFactory;
 
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Properties;
-
-import static org.apache.commons.lang3.StringEscapeUtils.escapeEcmaScript;
 
 /**
  * Livy SparkSQL Interpreter for Zeppelin.
  */
 public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
+
   public static final String ZEPPELIN_LIVY_SPARK_SQL_FIELD_TRUNCATE =
       "zeppelin.livy.spark.sql.field.truncate";
 
@@ -45,7 +55,6 @@ public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
       "zeppelin.livy.spark.sql.maxResult";
 
   private LivySparkInterpreter sparkInterpreter;
-  private String codeType = null;
 
   private boolean isSpark2 = false;
   private int maxResult = 1000;
@@ -72,7 +81,7 @@ public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
     // to judge whether it is using spark2.
     try {
       InterpreterContext context = InterpreterContext.builder()
-          .setInterpreterOut(new InterpreterOutput(null))
+          .setInterpreterOut(new InterpreterOutput())
           .build();
       InterpreterResult result = sparkInterpreter.interpret("spark", context);
       if (result.code() == InterpreterResult.Code.SUCCESS &&
@@ -113,8 +122,17 @@ public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
       // use triple quote so that we don't need to do string escape.
       String sqlQuery = null;
       if (isSpark2) {
-        sqlQuery = "spark.sql(\"\"\"" + line + "\"\"\").show(" + maxResult + ", " +
-            truncate + ")";
+        if (tableWithUTFCharacter()) {
+          sqlQuery = "val df = spark.sql(\"\"\"" + line + "\"\"\")\n"
+              + "for ( col <- df.columns ) {\n"
+              + "    print(col+\"\\t\")\n"
+              + "}\n"
+              + "println\n"
+              + "df.toJSON.take(" + maxResult + ").foreach(println)";
+        } else {
+          sqlQuery = "spark.sql(\"\"\"" + line + "\"\"\").show(" + maxResult + ", " +
+              truncate + ")";
+        }
       } else {
         sqlQuery = "sqlContext.sql(\"\"\"" + line + "\"\"\").show(" + maxResult + ", " +
             truncate + ")";
@@ -127,7 +145,12 @@ public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
           // assumption is correct for now. Ideally livy should return table type. We may do it in
           // the future release of livy.
           if (message.getType() == InterpreterResult.Type.TEXT) {
-            List<String> rows = parseSQLOutput(message.getData());
+            List<String> rows;
+            if (tableWithUTFCharacter()) {
+              rows = parseSQLJsonOutput(message.getData());
+            } else {
+              rows = parseSQLOutput(message.getData());
+            }
             result2.add(InterpreterResult.Type.TABLE, StringUtils.join(rows, "\n"));
             if (rows.size() >= (maxResult + 1)) {
               result2.add(ResultMessages.getExceedsLimitRowsMessage(maxResult,
@@ -153,7 +176,46 @@ public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
     return FormType.SIMPLE;
   }
 
-  protected List<String> parseSQLOutput(String output) {
+  protected List<String> parseSQLJsonOutput(String output) {
+    List<String> rows = new ArrayList<>();
+
+    String[] rowsOutput = output.split("(?<!\\\\)\\n");
+    String[] header = rowsOutput[1].split("\t");
+    List<String> cells = new ArrayList<>(Arrays.asList(header));
+    rows.add(StringUtils.join(cells, "\t"));
+
+    for (int i = 2; i < rowsOutput.length; i++) {
+      Map<String, String> retMap = new Gson().fromJson(
+          rowsOutput[i], new TypeToken<HashMap<String, String>>() {
+          }.getType()
+      );
+      cells = new ArrayList<>();
+      for (String s : header) {
+        cells.add(retMap.getOrDefault(s, "null")
+            .replace("\n", "\\n")
+            .replace("\t", "\\t"));
+      }
+      rows.add(StringUtils.join(cells, "\t"));
+    }
+    return rows;
+  }
+
+  protected List<String> parseSQLOutput(String str) {
+    // the regex is referred to org.apache.spark.util.Utils#fullWidthRegex
+    // for spark every chinese character has two placeholder(one placeholder is one char)
+    // for zeppelin it has only one placeholder.
+    // insert a special character (/u0001) which never use after every chinese character
+    String fullWidthRegex = "([" +
+            "\u1100-\u115F" +
+            "\u2E80-\uA4CF" +
+            "\uAC00-\uD7A3" +
+            "\uF900-\uFAFF" +
+            "\uFE10-\uFE19" +
+            "\uFE30-\uFE6F" +
+            "\uFF00-\uFF60" +
+            "\uFFE0-\uFFE6" +
+            "])";
+    String output = str.replaceAll(fullWidthRegex, "$1\u0001");
     List<String> rows = new ArrayList<>();
     // Get first line by breaking on \n. We can guarantee
     // that \n marks the end of the first line, but not for
@@ -191,7 +253,12 @@ public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
         List<String> cells = new ArrayList<>();
         for (Pair pair : pairs) {
           // strip the blank space around the cell and escape the string
-          cells.add(escapeEcmaScript(line.substring(pair.start, pair.end)).trim());
+          // replace /u0001 with empty string just because we insert it before
+          // escapeJavaStyleString is referred to
+          // org.apache.commons.lang3.StringEscapeUtils.escapeEcmaScript
+          // but make a little change that avoid chinese character is escaped
+          cells.add(escapeJavaStyleString(line.substring(pair.start, pair.end)
+                          .replaceAll("\u0001", "")).trim());
         }
         rows.add(StringUtils.join(cells, "\t"));
       }
@@ -202,10 +269,102 @@ public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
     return rows;
   }
 
+  private static String escapeJavaStyleString(String str) {
+    if (str == null) {
+      return null;
+    }
+    try {
+      StringWriter writer = new StringWriter(str.length() * 2);
+      escapeJavaStyleString(writer, str);
+      return writer.toString();
+    } catch (IOException ioe) {
+      // this should never ever happen while writing to a StringWriter
+      throw new RuntimeException(ioe);
+    }
+  }
+
+  private static void escapeJavaStyleString(Writer out, String str) throws IOException {
+    if (out == null) {
+      throw new IllegalArgumentException("The Writer must not be null");
+    }
+    if (str == null) {
+      return;
+    }
+    int sz;
+    sz = str.length();
+    for (int i = 0; i < sz; i++) {
+      char ch = str.charAt(i);
+
+      // handle unicode
+      if (ch > 0xfff) {
+        out.write(ch);
+      } else if (ch > 0xff) {
+        out.write("\\u0" + hex(ch));
+      } else if (ch > 0x7f) {
+        out.write("\\u00" + hex(ch));
+      } else if (ch < 32) {
+        switch (ch) {
+          case '\b' :
+            out.write('\\');
+            out.write('b');
+            break;
+          case '\n' :
+            out.write('\\');
+            out.write('n');
+            break;
+          case '\t' :
+            out.write('\\');
+            out.write('t');
+            break;
+          case '\f' :
+            out.write('\\');
+            out.write('f');
+            break;
+          case '\r' :
+            out.write('\\');
+            out.write('r');
+            break;
+          default :
+            if (ch > 0xf) {
+              out.write("\\u00" + hex(ch));
+            } else {
+              out.write("\\u000" + hex(ch));
+            }
+            break;
+        }
+      } else {
+        switch (ch) {
+          case '\'' :
+            out.write('\\');
+            break;
+          case '"' :
+            out.write('\\');
+            out.write('"');
+            break;
+          case '\\' :
+            out.write('\\');
+            out.write('\\');
+            break;
+          case '/' :
+            out.write('\\');
+            break;
+          default :
+            out.write(ch);
+            break;
+        }
+      }
+    }
+  }
+
+  private static String hex(char ch) {
+    return Integer.toHexString(ch).toUpperCase(Locale.ENGLISH);
+  }
+
   /**
    * Represent the start and end index of each cell.
    */
   private static class Pair {
+
     private int start;
     private int end;
 
@@ -219,6 +378,10 @@ public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
     return Boolean.parseBoolean(getProperty("zeppelin.livy.concurrentSQL"));
   }
 
+  public boolean tableWithUTFCharacter() {
+    return Boolean.parseBoolean(getProperty("zeppelin.livy.tableWithUTFCharacter"));
+  }
+
   @Override
   public Scheduler getScheduler() {
     if (concurrentSQL()) {
@@ -229,7 +392,7 @@ public class LivySparkSQLInterpreter extends BaseLivyInterpreter {
       if (sparkInterpreter != null) {
         return sparkInterpreter.getScheduler();
       } else {
-        return null;
+        return super.getScheduler();
       }
     }
   }
