@@ -88,7 +88,9 @@ public class ZeppelinClient {
     }
     if (response.getStatus() != 200) {
       String message = response.getStatusText();
-      if (response.getBody().getObject().has("message")) {
+      if (response.getBody() != null &&
+              response.getBody().getObject() != null &&
+              response.getBody().getObject().has("message")) {
         message = response.getBody().getObject().getString("message");
       }
       throw new Exception(String.format("Unable to call rest api, status: %s, statusText: %s, message: %s",
@@ -330,6 +332,44 @@ public class ZeppelinClient {
     checkJsonNodeStatus(jsonNode);
   }
 
+  /**
+   * Clone a note to a specified notePath.
+   *
+   * @param noteId
+   * @param destPath
+   * @return
+   * @throws Exception
+   */
+  public String cloneNote(String noteId, String destPath) throws Exception {
+    JSONObject bodyObject = new JSONObject();
+    bodyObject.put("name", destPath);
+    HttpResponse<JsonNode> response = Unirest
+            .post("/notebook/{noteId}")
+            .routeParam("noteId", noteId)
+            .body(bodyObject.toString())
+            .asJson();
+    checkResponse(response);
+    JsonNode jsonNode = response.getBody();
+    checkJsonNodeStatus(jsonNode);
+
+    return jsonNode.getObject().getString("body");
+  }
+
+  public void renameNote(String noteId, String newNotePath) throws Exception {
+    JSONObject bodyObject = new JSONObject();
+    bodyObject.put("name", newNotePath);
+
+    HttpResponse<JsonNode> response = Unirest
+            .put("/notebook/{noteId}/rename")
+            .routeParam("noteId", noteId)
+            .body(bodyObject.toString())
+            .asJson();
+
+    checkResponse(response);
+    JsonNode jsonNode = response.getBody();
+    checkJsonNodeStatus(jsonNode);
+  }
+
   /**
    * Query {@link NoteResult} with provided noteId.
    *
@@ -355,6 +395,11 @@ public class ZeppelinClient {
       }
     }
 
+    String notePath = null;
+    if (noteJsonObject.has("path")) {
+      notePath = noteJsonObject.getString("path");
+    }
+
     List<ParagraphResult> paragraphResultList = new ArrayList<>();
     if (noteJsonObject.has("paragraphs")) {
       JSONArray paragraphJsonArray = noteJsonObject.getJSONArray("paragraphs");
@@ -363,7 +408,7 @@ public class ZeppelinClient {
       }
     }
 
-    return new NoteResult(noteId, isRunning, paragraphResultList);
+    return new NoteResult(noteId, notePath, isRunning, paragraphResultList);
   }
 
   /**
