@@ -153,7 +153,7 @@ public abstract class FlinkIntegrationTest {
     flinkInterpreterSetting.setProperty("FLINK_HOME", flinkHome);
     flinkInterpreterSetting.setProperty("PATH", hadoopHome + "/bin:" + System.getenv("PATH"));
     flinkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zeppelin.getZeppelinConfDir().getAbsolutePath());
-    flinkInterpreterSetting.setProperty("flink.execution.mode", "YARN");
+    flinkInterpreterSetting.setProperty("flink.execution.mode", "yarn");
     flinkInterpreterSetting.setProperty("zeppelin.flink.run.asLoginUser", "false");
 
     testInterpreterBasics();
