@@ -77,7 +77,6 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import java.io.IOException;
 import java.lang.reflect.Constructor;
-import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.net.URL;
 import java.nio.ByteBuffer;
@@ -142,6 +141,12 @@ public class RemoteInterpreterServer extends Thread
   private ScheduledExecutorService resultCleanService = Executors.newSingleThreadScheduledExecutor();
 
   private boolean isTest;
+  // Whether calling System.exit to force shutdown interpreter process.
+  // In Flink K8s application mode, RemoteInterpreterServer#main is called via reflection by flink framework.
+  // We should not call System.exit in this scenario when RemoteInterpreterServer is stopped,
+  // Otherwise flink will think flink job is exited abnormally and will try to restart this
+  // pod (RemoteInterpreterServer)
+  private boolean isForceShutdown = true;
 
   private ZeppelinConfiguration zConf;
   // cluster manager client
@@ -321,7 +326,10 @@ public class RemoteInterpreterServer extends Thread
      * should be part of the next release and solve the problem.
      * We may have other threads that are not terminated successfully.
      */
-    System.exit(0);
+    if (remoteInterpreterServer.isForceShutdown) {
+      LOGGER.info("Force shutting down");
+      System.exit(0);
+    }
   }
 
   // Submit interpreter process metadata information to cluster metadata
@@ -380,11 +388,14 @@ public class RemoteInterpreterServer extends Thread
               replClass.getConstructor(new Class[]{Properties.class});
       Interpreter interpreter = constructor.newInstance(p);
       interpreter.setClassloaderUrls(new URL[]{});
-      LOGGER.info("Instantiate interpreter {}", className);
+
       interpreter.setInterpreterGroup(interpreterGroup);
       interpreter.setUserName(userName);
 
       interpreterGroup.addInterpreterToSession(new LazyOpenInterpreter(interpreter), sessionId);
+
+      this.isForceShutdown = Boolean.parseBoolean(properties.getOrDefault("zeppelin.interpreter.forceShutdown", "true"));
+      LOGGER.info("Instantiate interpreter {}, isForceShutdown: {}", className, isForceShutdown);
     } catch (Exception e) {
       LOGGER.error(e.getMessage(), e);
       throw new InterpreterRPCException("Fail to create interpreter, cause: " + e.toString());
@@ -700,7 +711,7 @@ public class RemoteInterpreterServer extends Thread
         }
       }
 
-      if (server.isServing()) {
+      if (server.isServing() && isForceShutdown) {
         LOGGER.info("Force shutting down");
         System.exit(1);
       }
