@@ -18,6 +18,7 @@
 package org.apache.zeppelin.interpreter.launcher;
 
 import com.google.common.base.CharMatcher;
+import com.google.common.collect.Sets;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.interpreter.recovery.RecoveryStorage;
@@ -26,18 +27,20 @@ import org.slf4j.LoggerFactory;
 
 import java.io.File;
 import java.io.IOException;
-import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.StringJoiner;
+import java.util.Set;
 import java.util.stream.Collectors;
 
 public class FlinkInterpreterLauncher extends StandardInterpreterLauncher {
 
   private static final Logger LOGGER = LoggerFactory.getLogger(FlinkInterpreterLauncher.class);
-
+  private static final Set<String> FLINK_EXECUTION_MODES = Sets.newHashSet(
+          "local", "remote", "yarn", "yarn-application", "kubernetes-application");
 
   public FlinkInterpreterLauncher(ZeppelinConfiguration zConf, RecoveryStorage recoveryStorage) {
     super(zConf, recoveryStorage);
@@ -48,8 +51,8 @@ public class FlinkInterpreterLauncher extends StandardInterpreterLauncher {
           throws IOException {
     Map<String, String> envs = super.buildEnvFromProperties(context);
 
-    String flinkHome = updateEnvsForFlinkHome(envs, context);
-
+    // update FLINK related environment variables
+    String flinkHome = getFlinkHome(context);
     if (!envs.containsKey("FLINK_CONF_DIR")) {
       envs.put("FLINK_CONF_DIR", flinkHome + "/conf");
     }
@@ -59,14 +62,29 @@ public class FlinkInterpreterLauncher extends StandardInterpreterLauncher {
     normalizeConfiguration(context);
 
     String flinkExecutionMode = context.getProperties().getProperty("flink.execution.mode");
-    // yarn application mode specific logic
-    if ("yarn-application".equalsIgnoreCase(flinkExecutionMode)) {
-      updateEnvsForYarnApplicationMode(envs, context);
+    if (!FLINK_EXECUTION_MODES.contains(flinkExecutionMode)) {
+      throw new IOException("Not valid flink.execution.mode: " +
+              flinkExecutionMode + ", valid modes ares: " +
+              FLINK_EXECUTION_MODES.stream().collect(Collectors.joining(", ")));
+    }
+    // application mode specific logic
+    if (isApplicationMode(flinkExecutionMode)) {
+      updateEnvsForApplicationMode(flinkExecutionMode, envs, context);
     }
 
-    String flinkAppJar = chooseFlinkAppJar(flinkHome);
-    LOGGER.info("Choose FLINK_APP_JAR: {}", flinkAppJar);
-    envs.put("FLINK_APP_JAR", flinkAppJar);
+    if (isK8sApplicationMode(flinkExecutionMode)) {
+      String flinkAppJar = context.getProperties().getProperty("flink.app.jar");
+      if (StringUtils.isBlank(flinkAppJar)) {
+        throw new IOException("flink.app.jar is not specified for kubernetes-application mode");
+      }
+      envs.put("FLINK_APP_JAR", flinkAppJar);
+      LOGGER.info("K8s application's FLINK_APP_JAR : " + flinkAppJar);
+      context.getProperties().put("zeppelin.interpreter.forceShutdown", "false");
+    } else {
+      String flinkAppJar = chooseFlinkAppJar(flinkHome);
+      LOGGER.info("Choose FLINK_APP_JAR for non k8s-application mode: {}", flinkAppJar);
+      envs.put("FLINK_APP_JAR", flinkAppJar);
+    }
 
     if ("yarn".equalsIgnoreCase(flinkExecutionMode) ||
             "yarn-application".equalsIgnoreCase(flinkExecutionMode)) {
@@ -148,8 +166,28 @@ public class FlinkInterpreterLauncher extends StandardInterpreterLauncher {
     return flinkScalaJars.get(0).getAbsolutePath();
   }
 
-  private String updateEnvsForFlinkHome(Map<String, String> envs,
-                                      InterpreterLaunchContext context) throws IOException {
+  private boolean isApplicationMode(String mode) {
+    return isYarnApplicationMode(mode) || isK8sApplicationMode(mode);
+  }
+
+  private boolean isYarnApplicationMode(String mode) {
+    return "yarn-application".equals(mode);
+  }
+
+  private boolean isK8sApplicationMode(String mode) {
+    return "kubernetes-application".equals(mode);
+  }
+
+  /**
+   * Get FLINK_HOME in the following orders:
+   *    1. FLINK_HOME in interpreter setting
+   *    2. FLINK_HOME in system environment variables.
+   *
+   * @param context
+   * @return
+   * @throws IOException
+   */
+  private String getFlinkHome(InterpreterLaunchContext context) throws IOException {
     String flinkHome = context.getProperties().getProperty("FLINK_HOME");
     if (StringUtils.isBlank(flinkHome)) {
       flinkHome = System.getenv("FLINK_HOME");
@@ -168,11 +206,11 @@ public class FlinkInterpreterLauncher extends StandardInterpreterLauncher {
     return flinkHome;
   }
 
-  private void updateEnvsForYarnApplicationMode(Map<String, String> envs,
-                                                InterpreterLaunchContext context)
-          throws IOException {
-
-    envs.put("ZEPPELIN_FLINK_YARN_APPLICATION", "true");
+  private void updateEnvsForApplicationMode(String mode,
+                                            Map<String, String> envs,
+                                            InterpreterLaunchContext context) throws IOException {
+    // ZEPPELIN_FLINK_APPLICATION_MODE is used in interpreter.sh
+    envs.put("ZEPPELIN_FLINK_APPLICATION_MODE", mode);
 
     StringJoiner flinkConfStringJoiner = new StringJoiner("|");
     // set yarn.ship-files
@@ -190,7 +228,7 @@ public class FlinkInterpreterLauncher extends StandardInterpreterLauncher {
       flinkConfStringJoiner.add("yarn.application.name=" + yarnAppName);
     }
 
-    // add other yarn and python configuration.
+    // add other configuration for both k8s and yarn
     for (Map.Entry<Object, Object> entry : context.getProperties().entrySet()) {
       String key = entry.getKey().toString();
       String value = entry.getValue().toString();
@@ -205,9 +243,16 @@ public class FlinkInterpreterLauncher extends StandardInterpreterLauncher {
         }
       }
     }
-    envs.put("ZEPPELIN_FLINK_YARN_APPLICATION_CONF", flinkConfStringJoiner.toString());
+    envs.put("ZEPPELIN_FLINK_APPLICATION_MODE_CONF", flinkConfStringJoiner.toString());
   }
 
+  /**
+   * Used in yarn-application mode.
+   *
+   * @param context
+   * @return
+   * @throws IOException
+   */
   private List<String> getYarnShipFiles(InterpreterLaunchContext context) throws IOException {
     // Extract yarn.ship-files, add hive-site.xml automatically if hive is enabled
     // and HIVE_CONF_DIR is specified
