@@ -14,55 +14,65 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.zeppelin.rest;
 
 import com.google.gson.JsonElement;
 import com.google.gson.JsonParseException;
 import com.google.gson.JsonParser;
-import java.io.File;
-import java.io.IOException;
-import java.lang.ref.WeakReference;
-import java.net.InetAddress;
-import java.net.UnknownHostException;
-import java.util.List;
-import java.util.Map;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
-import java.util.regex.Pattern;
+
 import org.apache.commons.exec.CommandLine;
 import org.apache.commons.exec.DefaultExecutor;
 import org.apache.commons.exec.PumpStreamHandler;
-import org.apache.commons.httpclient.Header;
-import org.apache.commons.httpclient.HttpClient;
-import org.apache.commons.httpclient.HttpMethodBase;
-import org.apache.commons.httpclient.cookie.CookiePolicy;
-import org.apache.commons.httpclient.methods.ByteArrayRequestEntity;
-import org.apache.commons.httpclient.methods.DeleteMethod;
-import org.apache.commons.httpclient.methods.GetMethod;
-import org.apache.commons.httpclient.methods.PostMethod;
-import org.apache.commons.httpclient.methods.PutMethod;
-import org.apache.commons.httpclient.methods.RequestEntity;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.zeppelin.conf.ZeppelinConfiguration;
-import org.apache.zeppelin.interpreter.InterpreterProperty;
-import org.apache.zeppelin.interpreter.InterpreterPropertyType;
-import org.apache.zeppelin.interpreter.InterpreterSetting;
-import org.apache.zeppelin.server.ZeppelinServer;
+import org.apache.http.Header;
+import org.apache.http.HttpResponse;
+import org.apache.http.HttpStatus;
+import org.apache.http.NameValuePair;
+import org.apache.http.client.config.CookieSpecs;
+import org.apache.http.client.config.RequestConfig;
+import org.apache.http.client.entity.UrlEncodedFormEntity;
+import org.apache.http.client.methods.CloseableHttpResponse;
+import org.apache.http.client.methods.HttpDelete;
+import org.apache.http.client.methods.HttpGet;
+import org.apache.http.client.methods.HttpPost;
+import org.apache.http.client.methods.HttpPut;
+import org.apache.http.entity.ContentType;
+import org.apache.http.entity.StringEntity;
+import org.apache.http.impl.client.CloseableHttpClient;
+import org.apache.http.impl.client.HttpClients;
+import org.apache.http.message.BasicNameValuePair;
+import org.apache.zeppelin.notebook.Notebook;
+import org.apache.zeppelin.plugin.PluginManager;
+import org.apache.zeppelin.utils.TestUtils;
 import org.hamcrest.Description;
 import org.hamcrest.Matcher;
 import org.hamcrest.TypeSafeMatcher;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-public abstract class AbstractTestRestApi {
+import java.io.File;
+import java.io.IOException;
+import java.lang.ref.WeakReference;
+import java.net.InetAddress;
+import java.net.UnknownHostException;
+import java.nio.charset.StandardCharsets;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.regex.Pattern;
 
+import org.apache.zeppelin.conf.ZeppelinConfiguration;
+import org.apache.zeppelin.interpreter.InterpreterSetting;
+import org.apache.zeppelin.server.ZeppelinServer;
+
+public abstract class AbstractTestRestApi {
   protected static final Logger LOG = LoggerFactory.getLogger(AbstractTestRestApi.class);
 
-  static final String restApiUrl = "/api";
-  static final String url = getUrlToTest();
-  protected static final boolean wasRunning = checkIfServerIsRunning();
+  public static final String REST_API_URL = "/api";
+  static final String URL = getUrlToTest();
+  protected static final boolean WAS_RUNNING = checkIfServerIsRunning();
   static boolean isRunningWithAuth = false;
 
   private static File shiroIni = null;
@@ -84,13 +94,11 @@ public abstract class AbstractTestRestApi {
           "admin = *\n" +
           "[urls]\n" +
           "/api/version = anon\n" +
+          "/api/cluster/address = anon\n" +
           "/** = authc";
 
   private static String zeppelinShiroKnox =
-      "[users]\n" +
-          "admin = password1, admin\n" +
-          "user1 = password2, role1, role2\n" +
-          "[main]\n" +
+           "[main]\n" +
           "knoxJwtRealm = org.apache.zeppelin.realm.jwt.KnoxJwtRealm\n" +
           "knoxJwtRealm.providerUrl = https://domain.example.com/\n" +
           "knoxJwtRealm.login = gateway/knoxsso/knoxauth/login.html\n" +
@@ -107,10 +115,11 @@ public abstract class AbstractTestRestApi {
           "admin = *\n" +
           "[urls]\n" +
           "/api/version = anon\n" +
+          "/api/cluster/address = anon\n" +
           "/** = authc";
 
   private static File knoxSsoPem = null;
-  private static String KNOX_SSO_PEM =
+  private static String knoxSsoPemCertificate =
       "-----BEGIN CERTIFICATE-----\n"
           + "MIIChjCCAe+gAwIBAgIJALYrdDEXKwcqMA0GCSqGSIb3DQEBBQUAMIGEMQswCQYD\n"
           + "VQQGEwJVUzENMAsGA1UECBMEVGVzdDENMAsGA1UEBxMEVGVzdDEPMA0GA1UEChMG\n"
@@ -130,6 +139,16 @@ public abstract class AbstractTestRestApi {
 
   protected static File zeppelinHome;
   protected static File confDir;
+  protected static File notebookDir;
+
+  private static CloseableHttpClient httpClient;
+
+  public static CloseableHttpClient getHttpClient() {
+    if (httpClient == null) {
+      httpClient = HttpClients.createDefault();
+    }
+    return httpClient;
+  }
 
   private String getUrl(String path) {
     String url;
@@ -138,14 +157,16 @@ public abstract class AbstractTestRestApi {
     } else {
       url = "http://localhost:8080";
     }
-    url += restApiUrl;
-    if (path != null)
+    url += REST_API_URL;
+    if (path != null) {
       url += path;
+    }
+
     return url;
   }
 
   protected static String getUrlToTest() {
-    String url = "http://localhost:8080" + restApiUrl;
+    String url = "http://localhost:8080" + REST_API_URL;
     if (System.getProperty("url") != null) {
       url = System.getProperty("url");
     }
@@ -153,41 +174,69 @@ public abstract class AbstractTestRestApi {
   }
 
   static ExecutorService executor;
-  protected static final Runnable server = new Runnable() {
+  protected static final Runnable SERVER = new Runnable() {
     @Override
     public void run() {
       try {
+        TestUtils.clearInstances();
         ZeppelinServer.main(new String[]{""});
-      } catch (Exception e) {
+      } catch (Throwable e) {
         LOG.error("Exception in WebDriverManager while getWebDriver ", e);
         throw new RuntimeException(e);
       }
     }
   };
 
-  private static void start(boolean withAuth, String testClassName, boolean withKnox) throws Exception {
-    if (!wasRunning) {
+  private static void start(boolean withAuth,
+                            String testClassName,
+                            boolean withKnox,
+                            boolean cleanData)
+          throws Exception {
+    LOG.info("Starting ZeppelinServer withAuth: {}, testClassName: {}, withKnox: {}",
+        withAuth, testClassName, withKnox);
+
+    if (!WAS_RUNNING) {
+      ZeppelinConfiguration.reset();
       // copy the resources files to a temp folder
       zeppelinHome = new File("..");
       LOG.info("ZEPPELIN_HOME: " + zeppelinHome.getAbsolutePath());
       confDir = new File(zeppelinHome, "conf_" + testClassName);
+      FileUtils.deleteDirectory(confDir);
+      LOG.info("ZEPPELIN_CONF_DIR: " + confDir.getAbsolutePath());
       confDir.mkdirs();
 
-      System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_HOME.getVarName(), zeppelinHome.getAbsolutePath());
-      System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_WAR.getVarName(), new File("../zeppelin-web/dist").getAbsolutePath());
-      System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_CONF_DIR.getVarName(), confDir.getAbsolutePath());
+      System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_HOME.getVarName(),
+          zeppelinHome.getAbsolutePath());
+      System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_WAR.getVarName(),
+          new File("../zeppelin-web/dist").getAbsolutePath());
+      System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_ANGULAR_WAR.getVarName(),
+              new File("../zeppelin-web-angular/dist").getAbsolutePath());
+      System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_CONF_DIR.getVarName(),
+          confDir.getAbsolutePath());
+      System.setProperty(
+          ZeppelinConfiguration.ConfVars.ZEPPELIN_INTERPRETER_GROUP_DEFAULT.getVarName(),
+          "spark");
+
+      notebookDir = new File(zeppelinHome.getAbsolutePath() + "/notebook_" + testClassName);
+      if (cleanData) {
+        FileUtils.deleteDirectory(notebookDir);
+      }
+      System.setProperty(
+          ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_DIR.getVarName(),
+          notebookDir.getPath()
+      );
 
       // some test profile does not build zeppelin-web.
       // to prevent zeppelin starting up fail, create zeppelin-web/dist directory
       new File("../zeppelin-web/dist").mkdirs();
+      new File("../zeppelin-web-angular/dist").mkdirs();
 
-      LOG.info("Staring test Zeppelin up...");
+      LOG.info("Starting Zeppelin Server...");
       ZeppelinConfiguration conf = ZeppelinConfiguration.create();
+      LOG.info("zconf.getClusterAddress() = {}", conf.getClusterAddress());
 
       if (withAuth) {
         isRunningWithAuth = true;
-        // Set Anonymous session to false.
-        System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_ANONYMOUS_ALLOWED.getVarName(), "false");
 
         // Create a shiro env test.
         shiroIni = new File(confDir, "shiro.ini");
@@ -196,41 +245,21 @@ public abstract class AbstractTestRestApi {
         }
         if (withKnox) {
           FileUtils.writeStringToFile(shiroIni,
-              zeppelinShiroKnox.replaceAll("knox-sso.pem", confDir + "/knox-sso.pem"));
+              zeppelinShiroKnox.replaceAll("knox-sso.pem", confDir + "/knox-sso.pem"),
+              StandardCharsets.UTF_8);
           knoxSsoPem = new File(confDir, "knox-sso.pem");
           if (!knoxSsoPem.exists()) {
             knoxSsoPem.createNewFile();
           }
-          FileUtils.writeStringToFile(knoxSsoPem, KNOX_SSO_PEM);
+          FileUtils.writeStringToFile(knoxSsoPem, knoxSsoPemCertificate, StandardCharsets.UTF_8);
         } else {
-          FileUtils.writeStringToFile(shiroIni, zeppelinShiro);
+          FileUtils.writeStringToFile(shiroIni, zeppelinShiro, StandardCharsets.UTF_8);
         }
 
       }
 
-      // exclude org.apache.zeppelin.rinterpreter.* for scala 2.11 test
-      String interpreters = conf.getString(ZeppelinConfiguration.ConfVars.ZEPPELIN_INTERPRETERS);
-      String interpretersCompatibleWithScala211Test = null;
-
-      for (String intp : interpreters.split(",")) {
-        if (intp.startsWith("org.apache.zeppelin.rinterpreter")) {
-          continue;
-        }
-
-        if (interpretersCompatibleWithScala211Test == null) {
-          interpretersCompatibleWithScala211Test = intp;
-        } else {
-          interpretersCompatibleWithScala211Test += "," + intp;
-        }
-      }
-
-      System.setProperty(
-          ZeppelinConfiguration.ConfVars.ZEPPELIN_INTERPRETERS.getVarName(),
-          interpretersCompatibleWithScala211Test);
-
-
       executor = Executors.newSingleThreadExecutor();
-      executor.submit(server);
+      executor.submit(SERVER);
       long s = System.currentTimeMillis();
       boolean started = false;
       while (System.currentTimeMillis() - s < 1000 * 60 * 3) {  // 3 minutes
@@ -243,21 +272,25 @@ public abstract class AbstractTestRestApi {
       if (started == false) {
         throw new RuntimeException("Can not start Zeppelin server");
       }
-      LOG.info("Test Zeppelin stared.");
+
+      LOG.info("Zeppelin Server is started.");
     }
   }
 
-
   protected static void startUpWithKnoxEnable(String testClassName) throws Exception {
-    start(true, testClassName, true);
+    start(true, testClassName, true, true);
   }
-  
+
   protected static void startUpWithAuthenticationEnable(String testClassName) throws Exception {
-    start(true, testClassName, false);
+    start(true, testClassName, false, true);
   }
-  
+
   protected static void startUp(String testClassName) throws Exception {
-    start(false, testClassName, false);
+    start(false, testClassName, false, true);
+  }
+
+  protected static void startUp(String testClassName, boolean cleanData) throws Exception {
+    start(false, testClassName, false, cleanData);
   }
 
   private static String getHostname() {
@@ -274,20 +307,29 @@ public abstract class AbstractTestRestApi {
   }
 
   protected static void shutDown(final boolean deleteConfDir) throws Exception {
-    if (!wasRunning && ZeppelinServer.notebook != null) {
+    shutDown(deleteConfDir, false);
+  }
+
+  protected static void shutDown(final boolean deleteConfDir,
+                                 boolean forceShutdownInterpreter) throws Exception {
+
+    if (!WAS_RUNNING && TestUtils.getInstance(Notebook.class) != null) {
       // restart interpreter to stop all interpreter processes
-      List<InterpreterSetting> settingList = ZeppelinServer.notebook.getInterpreterSettingManager().get();
-      if (!ZeppelinServer.notebook.getConf().isRecoveryEnabled()) {
+      List<InterpreterSetting> settingList = TestUtils.getInstance(Notebook.class).getInterpreterSettingManager()
+              .get();
+      if (!TestUtils.getInstance(Notebook.class).getConf().isRecoveryEnabled() || forceShutdownInterpreter) {
         for (InterpreterSetting setting : settingList) {
-          ZeppelinServer.notebook.getInterpreterSettingManager().restart(setting.getId());
+          TestUtils.getInstance(Notebook.class).getInterpreterSettingManager().restart(setting.getId());
         }
       }
       if (shiroIni != null) {
         FileUtils.deleteQuietly(shiroIni);
       }
-      LOG.info("Terminating test Zeppelin...");
+      LOG.info("Terminating Zeppelin Server...");
       ZeppelinServer.jettyWebServer.stop();
       executor.shutdown();
+      PluginManager.reset();
+      ZeppelinConfiguration.reset();
 
       long s = System.currentTimeMillis();
       boolean started = true;
@@ -302,172 +344,164 @@ public abstract class AbstractTestRestApi {
         throw new RuntimeException("Can not stop Zeppelin server");
       }
 
-      LOG.info("Test Zeppelin terminated.");
+      LOG.info("Zeppelin Server is terminated.");
 
-      System.clearProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_INTERPRETERS.getVarName());
       if (isRunningWithAuth) {
-        isRunningWithAuth = false;
-        System
-            .clearProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_ANONYMOUS_ALLOWED.getVarName());
+        isRunningWithAuth = shiroIni.exists();
       }
 
-      if (deleteConfDir && !ZeppelinServer.notebook.getConf().isRecoveryEnabled()) {
+      if (deleteConfDir && !TestUtils.getInstance(Notebook.class).getConf().isRecoveryEnabled()) {
         // don't delete interpreter.json when recovery is enabled. otherwise the interpreter setting
         // id will change after zeppelin restart, then we can not recover interpreter process
         // properly
         FileUtils.deleteDirectory(confDir);
       }
+      TestUtils.clearInstances();
+      ZeppelinServer.reset();
     }
   }
 
-  protected static boolean checkIfServerIsRunning() {
-    GetMethod request = null;
-    boolean isRunning = true;
-    try {
-      request = httpGet("/version");
-      isRunning = request.getStatusCode() == 200;
+  public static boolean checkIfServerIsRunning() {
+    boolean isRunning;
+    try (CloseableHttpResponse response = httpGet("/version")) {
+      isRunning = response.getStatusLine().getStatusCode() == 200;
     } catch (IOException e) {
-      LOG.error("AbstractTestRestApi.checkIfServerIsRunning() fails .. ZeppelinServer is not running");
+      LOG.error("AbstractTestRestApi.checkIfServerIsRunning() fails .. ZeppelinServer is not " +
+          "running");
       isRunning = false;
-    } finally {
-      if (request != null) {
-        request.releaseConnection();
-      }
     }
     return isRunning;
   }
 
-  protected static GetMethod httpGet(String path) throws IOException {
+  public static CloseableHttpResponse httpGet(String path) throws IOException {
     return httpGet(path, StringUtils.EMPTY, StringUtils.EMPTY);
   }
-  
-  protected static GetMethod httpGet(String path, String user, String pwd) throws IOException {
+
+  public static CloseableHttpResponse httpGet(String path, String user, String pwd) throws IOException {
     return httpGet(path, user, pwd, StringUtils.EMPTY);
   }
 
-  protected static GetMethod httpGet(String path, String user, String pwd, String cookies) throws IOException {
-    LOG.info("Connecting to {}", url + path);
-    HttpClient httpClient = new HttpClient();
-    GetMethod getMethod = new GetMethod(url + path);
-    getMethod.addRequestHeader("Origin", url);
+  public static CloseableHttpResponse httpGet(String path, String user, String pwd, String cookies)
+    throws IOException {
+    LOG.info("Connecting to {}", URL + path);
+    HttpGet httpGet = new HttpGet(URL + path);
+    httpGet.addHeader("Origin", URL);
     if (userAndPasswordAreNotBlank(user, pwd)) {
-      getMethod.setRequestHeader("Cookie", "JSESSIONID="+ getCookie(user, pwd));
+      httpGet.setHeader("Cookie", "JSESSIONID=" + getCookie(user, pwd));
     }
     if (!StringUtils.isBlank(cookies)) {
-      getMethod.setRequestHeader("Cookie", getMethod.getResponseHeader("Cookie") + ";" + cookies);
+      httpGet.setHeader("Cookie", httpGet.getFirstHeader("Cookie") + ";" + cookies);
     }
-    httpClient.executeMethod(getMethod);
-    LOG.info("{} - {}", getMethod.getStatusCode(), getMethod.getStatusText());
-    return getMethod;
+    CloseableHttpResponse response = getHttpClient().execute(httpGet);
+    LOG.info("{} - {}", response.getStatusLine().getStatusCode(), response.getStatusLine().getReasonPhrase());
+    return response;
   }
 
-  protected static DeleteMethod httpDelete(String path) throws IOException {
+  public static CloseableHttpResponse httpDelete(String path) throws IOException {
     return httpDelete(path, StringUtils.EMPTY, StringUtils.EMPTY);
   }
 
-  protected static DeleteMethod httpDelete(String path, String user, String pwd) throws IOException {
-    LOG.info("Connecting to {}", url + path);
-    HttpClient httpClient = new HttpClient();
-    DeleteMethod deleteMethod = new DeleteMethod(url + path);
-    deleteMethod.addRequestHeader("Origin", url);
+  public static CloseableHttpResponse httpDelete(String path, String user, String pwd)
+      throws IOException {
+    LOG.info("Connecting to {}", URL + path);
+    HttpDelete httpDelete = new HttpDelete(URL + path);
+    httpDelete.addHeader("Origin", URL);
     if (userAndPasswordAreNotBlank(user, pwd)) {
-      deleteMethod.setRequestHeader("Cookie", "JSESSIONID="+ getCookie(user, pwd));
+      httpDelete.setHeader("Cookie", "JSESSIONID=" + getCookie(user, pwd));
     }
-    httpClient.executeMethod(deleteMethod);
-    LOG.info("{} - {}", deleteMethod.getStatusCode(), deleteMethod.getStatusText());
-    return deleteMethod;
+    CloseableHttpResponse response = getHttpClient().execute(httpDelete);
+    LOG.info("{} - {}", response.getStatusLine().getStatusCode(), response.getStatusLine().getReasonPhrase());
+    return response;
   }
 
-  protected static PostMethod httpPost(String path, String body) throws IOException {
+  public static CloseableHttpResponse httpPost(String path, String body) throws IOException {
     return httpPost(path, body, StringUtils.EMPTY, StringUtils.EMPTY);
   }
 
-  protected static PostMethod httpPost(String path, String request, String user, String pwd)
+  public static CloseableHttpResponse httpPost(String path, String request, String user, String pwd)
       throws IOException {
-    LOG.info("Connecting to {}", url + path);
-    HttpClient httpClient = new HttpClient();
-    PostMethod postMethod = new PostMethod(url + path);
-    postMethod.setRequestBody(request);
-    postMethod.getParams().setCookiePolicy(CookiePolicy.IGNORE_COOKIES);
+    LOG.info("Connecting to {}", URL + path);
+    RequestConfig localConfig = RequestConfig.custom()
+      .setCookieSpec(CookieSpecs.IGNORE_COOKIES)
+      .build();
+
+    HttpPost httpPost = new HttpPost(URL + path);
+    httpPost.setConfig(localConfig);
+    httpPost.setEntity(new StringEntity(request, ContentType.APPLICATION_JSON));
     if (userAndPasswordAreNotBlank(user, pwd)) {
-      postMethod.setRequestHeader("Cookie", "JSESSIONID="+ getCookie(user, pwd));
+      httpPost.setHeader("Cookie", "JSESSIONID=" + getCookie(user, pwd));
     }
-    httpClient.executeMethod(postMethod);
-    LOG.info("{} - {}", postMethod.getStatusCode(), postMethod.getStatusText());
-    return postMethod;
+    CloseableHttpResponse response = getHttpClient().execute(httpPost);
+    LOG.info("{} - {}", response.getStatusLine().getStatusCode(), response.getStatusLine().getReasonPhrase());
+    return response;
   }
 
-  protected static PutMethod httpPut(String path, String body) throws IOException {
+  public static CloseableHttpResponse httpPut(String path, String body) throws IOException {
     return httpPut(path, body, StringUtils.EMPTY, StringUtils.EMPTY);
   }
 
-  protected static PutMethod httpPut(String path, String body, String user, String pwd) throws IOException {
-    LOG.info("Connecting to {}", url + path);
-    HttpClient httpClient = new HttpClient();
-    PutMethod putMethod = new PutMethod(url + path);
-    putMethod.addRequestHeader("Origin", url);
-    RequestEntity entity = new ByteArrayRequestEntity(body.getBytes("UTF-8"));
-    putMethod.setRequestEntity(entity);
+  public static CloseableHttpResponse httpPut(String path, String body, String user, String pwd)
+      throws IOException {
+    LOG.info("Connecting to {}", URL + path);
+    HttpPut httpPut = new HttpPut(URL + path);
+    httpPut.addHeader("Origin", URL);
+    httpPut.setEntity(new StringEntity(body, ContentType.TEXT_PLAIN));
     if (userAndPasswordAreNotBlank(user, pwd)) {
-      putMethod.setRequestHeader("Cookie", "JSESSIONID="+ getCookie(user, pwd));
+      httpPut.setHeader("Cookie", "JSESSIONID=" + getCookie(user, pwd));
     }
-    httpClient.executeMethod(putMethod);
-    LOG.info("{} - {}", putMethod.getStatusCode(), putMethod.getStatusText());
-    return putMethod;
+    CloseableHttpResponse response = getHttpClient().execute(httpPut);
+    LOG.info("{} - {}", response.getStatusLine().getStatusCode(), response.getStatusLine().getReasonPhrase());
+    return response;
   }
 
   private static String getCookie(String user, String password) throws IOException {
-    HttpClient httpClient = new HttpClient();
-    PostMethod postMethod = new PostMethod(url + "/login");
-    postMethod.addRequestHeader("Origin", url);
-    postMethod.setParameter("password", password);
-    postMethod.setParameter("userName", user);
-    httpClient.executeMethod(postMethod);
-    LOG.info("{} - {}", postMethod.getStatusCode(), postMethod.getStatusText());
-    Pattern pattern = Pattern.compile("JSESSIONID=([a-zA-Z0-9-]*)");
-    Header[] setCookieHeaders = postMethod.getResponseHeaders("Set-Cookie");
-    String jsessionId = null;
-    for (Header setCookie : setCookieHeaders) {
-      java.util.regex.Matcher matcher = pattern.matcher(setCookie.toString());
-      if (matcher.find()) {
-        jsessionId = matcher.group(1);
+    HttpPost httpPost = new HttpPost(URL + "/login");
+    httpPost.addHeader("Origin", URL);
+    ArrayList<NameValuePair> postParameters = new ArrayList<NameValuePair>();
+    postParameters.add(new BasicNameValuePair("password", password));
+    postParameters.add(new BasicNameValuePair("userName", user));
+    httpPost.setEntity(new UrlEncodedFormEntity(postParameters, StandardCharsets.UTF_8));
+    try (CloseableHttpResponse response = getHttpClient().execute(httpPost)) {
+      LOG.info("{} - {}", response.getStatusLine().getStatusCode(), response.getStatusLine().getReasonPhrase());
+      Pattern pattern = Pattern.compile("JSESSIONID=([a-zA-Z0-9-]*)");
+      Header[] setCookieHeaders = response.getHeaders("Set-Cookie");
+      String jsessionId = null;
+      for (Header setCookie : setCookieHeaders) {
+        java.util.regex.Matcher matcher = pattern.matcher(setCookie.toString());
+        if (matcher.find()) {
+          jsessionId = matcher.group(1);
+        }
+      }
+      if (jsessionId != null) {
+        return jsessionId;
+      } else {
+        return StringUtils.EMPTY;
       }
-    }
-
-    if (jsessionId != null) {
-      return jsessionId;
-    } else {
-      return StringUtils.EMPTY;
     }
   }
 
   protected static boolean userAndPasswordAreNotBlank(String user, String pwd) {
-    if (StringUtils.isBlank(user) && StringUtils.isBlank(pwd)) {
-      return false;
-    }
-    return true;
+    return StringUtils.isNoneBlank(user, pwd);
   }
-  
-  protected Matcher<HttpMethodBase> responsesWith(final int expectedStatusCode) {
-    return new TypeSafeMatcher<HttpMethodBase>() {
-      WeakReference<HttpMethodBase> method;
+
+  protected static Matcher<HttpResponse> responsesWith(final int expectedStatusCode) {
+    return new TypeSafeMatcher<HttpResponse>() {
+      WeakReference<HttpResponse> response;
 
       @Override
-      public boolean matchesSafely(HttpMethodBase httpMethodBase) {
-        method = (method == null) ? new WeakReference<>(httpMethodBase) : method;
-        return httpMethodBase.getStatusCode() == expectedStatusCode;
+      public boolean matchesSafely(HttpResponse httpResponse) {
+        response = (response == null) ? new WeakReference<>(httpResponse) : response;
+        return httpResponse.getStatusLine().getStatusCode() == expectedStatusCode;
       }
 
       @Override
       public void describeTo(Description description) {
-        description.appendText("HTTP response ").appendValue(expectedStatusCode)
-            .appendText(" from ").appendText(method.get().getPath());
+        description.appendText("HTTP response ").appendValue(expectedStatusCode);
       }
 
       @Override
-      protected void describeMismatchSafely(HttpMethodBase item, Description description) {
-        description.appendText("got ").appendValue(item.getStatusCode()).appendText(" ")
-            .appendText(item.getStatusText());
+      protected void describeMismatchSafely(HttpResponse item, Description description) {
+        description.appendText("got ").appendValue(item.getStatusLine().getStatusCode());
       }
     };
   }
@@ -538,7 +572,6 @@ public abstract class AbstractTestRestApi {
     };
   }
 
-
   public static void ps() {
     DefaultExecutor executor = new DefaultExecutor();
     executor.setStreamHandler(new PumpStreamHandler(System.out, System.err));
@@ -553,22 +586,34 @@ public abstract class AbstractTestRestApi {
     }
   }
 
-
-  /** Status code matcher */
-  protected Matcher<? super HttpMethodBase> isForbidden() { return responsesWith(403); }
-
-  protected Matcher<? super HttpMethodBase> isAllowed() {
-    return responsesWith(200);
+  /**
+   * Status code matcher.
+   */
+  public static Matcher<? super HttpResponse> isForbidden() {
+    return responsesWith(HttpStatus.SC_FORBIDDEN);
   }
 
-  protected Matcher<? super HttpMethodBase> isCreated() { return responsesWith(201); }
-
-  protected Matcher<? super HttpMethodBase> isBadRequest() { return responsesWith(400); }
-
-  protected Matcher<? super HttpMethodBase> isNotFound() { return responsesWith(404); }
-
-  protected Matcher<? super HttpMethodBase> isNotAllowed() {
-    return responsesWith(405);
+  public static Matcher<? super HttpResponse> isAllowed() {
+    return responsesWith(HttpStatus.SC_OK);
   }
 
+  public static Matcher<? super HttpResponse> isCreated() {
+    return responsesWith(HttpStatus.SC_CREATED);
+  }
+
+  public static Matcher<? super HttpResponse> isBadRequest() {
+    return responsesWith(HttpStatus.SC_BAD_REQUEST);
+  }
+
+  public static Matcher<? super HttpResponse> isNotFound() {
+    return responsesWith(HttpStatus.SC_NOT_FOUND);
+  }
+
+  public static Matcher<? super HttpResponse> isNotAllowed() {
+    return responsesWith(HttpStatus.SC_METHOD_NOT_ALLOWED);
+  }
+
+  public static Matcher<? super HttpResponse> isExpectationFailed() {
+    return responsesWith(HttpStatus.SC_EXPECTATION_FAILED);
+  }
 }
