@@ -667,6 +667,11 @@ public class InterpreterSetting {
     this.dependencies = dependencies;
     if (!this.dependencies.isEmpty()) {
       loadInterpreterDependencies();
+    } else {
+      // Interpreter setting may be in ERROR due to download fail,
+      // reset status to be READY when dependency is cleaned.
+      setStatus(Status.READY);
+      setErrorReason(null);
     }
   }
 
@@ -757,6 +762,10 @@ public class InterpreterSetting {
 
   public String getLauncherPlugin(Properties properties) {
     if (isRunningOnKubernetes()) {
+      if (group.equals("flink")) {
+        // Flink has its own implementation of k8s mode.
+        return "FlinkInterpreterLauncher";
+      }
       return "K8sStandardInterpreterLauncher";
     } else if (isRunningOnCluster()) {
       return InterpreterSetting.CLUSTER_INTERPRETER_LAUNCHER_NAME;
