@@ -17,12 +17,20 @@
 package org.apache.zeppelin.notebook;
 
 import org.apache.zeppelin.scheduler.Job;
+import org.apache.zeppelin.user.AuthenticationInfo;
+
+import java.io.IOException;
 
 /**
- * NoteEventListener
+ * Notebook event
  */
 public interface NoteEventListener {
-  public void onParagraphRemove(Paragraph p);
-  public void onParagraphCreate(Paragraph p);
-  public void onParagraphStatusChange(Paragraph p, Job.Status status);
+  void onNoteRemove(Note note, AuthenticationInfo subject) throws IOException;
+  void onNoteCreate(Note note, AuthenticationInfo subject) throws IOException;
+  void onNoteUpdate(Note note, AuthenticationInfo subject) throws IOException;
+
+  void onParagraphRemove(Paragraph p) throws IOException;
+  void onParagraphCreate(Paragraph p) throws IOException;
+  void onParagraphUpdate(Paragraph p) throws IOException;
+  void onParagraphStatusChange(Paragraph p, Job.Status status) throws IOException;
 }
