@@ -1,19 +1,24 @@
 package org.apache.zeppelin.notebook;
 
+import com.google.common.annotations.VisibleForTesting;
+
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
 
 /**
  * Store runtime infos of each para
  *
  */
 public class ParagraphRuntimeInfo {
-
   private String propertyName;  // Name of the property
   private String label;         // Label to be used in UI
   private String tooltip;       // Tooltip text toshow in UI
   private String group;         // The interpretergroup from which the info was derived
-  private List<String> values;  // values for the property
+
+  // runtimeInfos job url or dropdown-menu key in
+  // zeppelin-web/src/app/notebook/paragraph/paragraph-control.html
+  private List<Object> values;  // values for the key-value pair property
   private String interpreterSettingId;
   
   public ParagraphRuntimeInfo(String propertyName, String label, 
@@ -29,8 +34,13 @@ public class ParagraphRuntimeInfo {
     this.values = new ArrayList<>();
   }
 
-  public void addValue(String value) {
-    values.add(value);
+  public void addValue(Map<String, String> mapValue) {
+    values.add(mapValue);
+  }
+
+  @VisibleForTesting
+  public List<Object> getValue() {
+    return values;
   }
   
   public String getInterpreterSettingId() {
