@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
 package org.apache.zeppelin.interpreter;
 
 import org.apache.commons.io.FileUtils;
@@ -6,6 +24,7 @@ import org.apache.zeppelin.display.AngularObjectRegistryListener;
 import org.apache.zeppelin.helium.ApplicationEventListener;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterProcessListener;
 import org.apache.zeppelin.notebook.Note;
+import org.apache.zeppelin.notebook.Notebook;
 import org.junit.After;
 import org.junit.Before;
 import org.slf4j.Logger;
@@ -14,6 +33,7 @@ import org.slf4j.LoggerFactory;
 import java.io.File;
 
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
 
 /**
  * This class will load configuration files under
@@ -28,6 +48,7 @@ public abstract class AbstractInterpreterTest {
 
   protected InterpreterSettingManager interpreterSettingManager;
   protected InterpreterFactory interpreterFactory;
+  protected Notebook mockNotebook;
   protected File zeppelinHome;
   protected File interpreterDir;
   protected File confDir;
@@ -61,14 +82,28 @@ public abstract class AbstractInterpreterTest {
     interpreterSettingManager = new InterpreterSettingManager(conf,
         mock(AngularObjectRegistryListener.class), mock(RemoteInterpreterProcessListener.class), mock(ApplicationEventListener.class));
     interpreterFactory = new InterpreterFactory(interpreterSettingManager);
+
+    mockNotebook = mock(Notebook.class);
+    interpreterSettingManager.setNotebook(mockNotebook);
   }
 
   @After
   public void tearDown() throws Exception {
-    interpreterSettingManager.close();
-    FileUtils.deleteDirectory(interpreterDir);
-    FileUtils.deleteDirectory(confDir);
-    FileUtils.deleteDirectory(notebookDir);
+    if (interpreterSettingManager != null) {
+      interpreterSettingManager.close();
+    }
+    if (interpreterDir != null) {
+      LOGGER.info("Delete interpreterDir: {}", interpreterDir);
+      FileUtils.deleteDirectory(interpreterDir);
+    }
+    if (confDir != null) {
+      LOGGER.info("Delete confDir: {}", confDir);
+      FileUtils.deleteDirectory(confDir);
+    }
+    if (notebookDir != null) {
+      LOGGER.info("Delete notebookDir: {}", notebookDir);
+      FileUtils.deleteDirectory(notebookDir);
+    }
   }
 
   protected Note createNote() {
