@@ -22,27 +22,26 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Mockito.mock;
 
+import com.google.common.io.Files;
 import java.io.File;
 import java.io.IOException;
 import java.util.HashSet;
-import java.util.List;
 import java.util.Map;
 import java.util.Set;
-
 import org.apache.commons.io.FileUtils;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.conf.ZeppelinConfiguration.ConfVars;
-import org.apache.zeppelin.dep.DependencyResolver;
 import org.apache.zeppelin.display.AngularObjectRegistryListener;
 import org.apache.zeppelin.helium.ApplicationEventListener;
 import org.apache.zeppelin.interpreter.InterpreterFactory;
-import org.apache.zeppelin.interpreter.InterpreterResultMessage;
 import org.apache.zeppelin.interpreter.InterpreterSettingManager;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterProcessListener;
-import org.apache.zeppelin.notebook.*;
-import org.apache.zeppelin.scheduler.Job;
-import org.apache.zeppelin.scheduler.Job.Status;
-import org.apache.zeppelin.scheduler.SchedulerFactory;
+import org.apache.zeppelin.notebook.AuthorizationService;
+import org.apache.zeppelin.notebook.Note;
+import org.apache.zeppelin.notebook.NoteInfo;
+import org.apache.zeppelin.notebook.NoteManager;
+import org.apache.zeppelin.notebook.Notebook;
+import org.apache.zeppelin.notebook.Paragraph;
 import org.apache.zeppelin.search.SearchService;
 import org.apache.zeppelin.storage.ConfigStorage;
 import org.apache.zeppelin.user.AuthenticationInfo;
@@ -54,43 +53,41 @@ import org.quartz.SchedulerException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+public class NotebookRepoSyncTest {
 
-public class NotebookRepoSyncTest implements JobListenerFactory {
-
-  private File mainZepDir;
+  private File ZEPPELIN_HOME;
   private ZeppelinConfiguration conf;
-  private SchedulerFactory schedulerFactory;
   private File mainNotebookDir;
   private File secNotebookDir;
-  private Notebook notebookSync;
+  private Notebook notebook;
   private NotebookRepoSync notebookRepoSync;
   private InterpreterFactory factory;
   private InterpreterSettingManager interpreterSettingManager;
-  private DependencyResolver depResolver;
   private SearchService search;
-  private NotebookAuthorization notebookAuthorization;
   private Credentials credentials;
   private AuthenticationInfo anonymous;
+  private NoteManager noteManager;
+  private AuthorizationService authorizationService;
   private static final Logger LOG = LoggerFactory.getLogger(NotebookRepoSyncTest.class);
 
   @Before
   public void setUp() throws Exception {
-    String zpath = System.getProperty("java.io.tmpdir")+"/ZeppelinLTest_"+System.currentTimeMillis();
-    mainZepDir = new File(zpath);
-    mainZepDir.mkdirs();
-    new File(mainZepDir, "conf").mkdirs();
-    String mainNotePath = zpath+"/notebook";
-    String secNotePath = mainNotePath + "_secondary";
+    System.setProperty("zeppelin.isTest", "true");
+    ZEPPELIN_HOME = Files.createTempDir();
+    new File(ZEPPELIN_HOME, "conf").mkdirs();
+    String mainNotePath = ZEPPELIN_HOME.getAbsolutePath() + "/notebook";
+    String secNotePath = ZEPPELIN_HOME.getAbsolutePath() + "/notebook_secondary";
     mainNotebookDir = new File(mainNotePath);
     secNotebookDir = new File(secNotePath);
     mainNotebookDir.mkdirs();
     secNotebookDir.mkdirs();
 
-    System.setProperty(ConfVars.ZEPPELIN_HOME.getVarName(), mainZepDir.getAbsolutePath());
+    System.setProperty(ConfVars.ZEPPELIN_HOME.getVarName(), ZEPPELIN_HOME.getAbsolutePath());
     System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_DIR.getVarName(), mainNotebookDir.getAbsolutePath());
     System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_STORAGE.getVarName(), "org.apache.zeppelin.notebook.repo.VFSNotebookRepo,org.apache.zeppelin.notebook.repo.mock.VFSNotebookRepoMock");
     System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_ONE_WAY_SYNC.getVarName(), "false");
-    System.setProperty(ConfVars.ZEPPELIN_CONFIG_FS_DIR.getVarName(), mainZepDir.getAbsolutePath() + "/conf");
+    System.setProperty(ConfVars.ZEPPELIN_CONFIG_FS_DIR.getVarName(), ZEPPELIN_HOME.getAbsolutePath() + "/conf");
+    System.setProperty(ConfVars.ZEPPELIN_PLUGINS_DIR.getVarName(), new File("../../../plugins").getAbsolutePath());
 
     LOG.info("main Note dir : " + mainNotePath);
     LOG.info("secondary note dir : " + secNotePath);
@@ -98,25 +95,23 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
 
     ConfigStorage.reset();
 
-    this.schedulerFactory = SchedulerFactory.singleton();
-
-    depResolver = new DependencyResolver(mainZepDir.getAbsolutePath() + "/local-repo");
     interpreterSettingManager = new InterpreterSettingManager(conf,
         mock(AngularObjectRegistryListener.class), mock(RemoteInterpreterProcessListener.class), mock(ApplicationEventListener.class));
     factory = new InterpreterFactory(interpreterSettingManager);
 
     search = mock(SearchService.class);
     notebookRepoSync = new NotebookRepoSync(conf);
-    notebookAuthorization = NotebookAuthorization.init(conf);
-    credentials = new Credentials(conf.credentialsPersist(), conf.getCredentialsPath(), null);
-    notebookSync = new Notebook(conf, notebookRepoSync, schedulerFactory, factory, interpreterSettingManager, this, search,
-            notebookAuthorization, credentials);
+    noteManager = new NoteManager(notebookRepoSync);
+    authorizationService = new AuthorizationService(noteManager, conf);
+    credentials = new Credentials(conf);
+    notebook = new Notebook(conf, authorizationService, notebookRepoSync, noteManager, factory, interpreterSettingManager, search, credentials, null);
     anonymous = new AuthenticationInfo("anonymous");
   }
 
   @After
   public void tearDown() throws Exception {
-    delete(mainZepDir);
+    delete(ZEPPELIN_HOME);
+    System.clearProperty("zeppelin.isTest");
   }
 
   @Test
@@ -132,14 +127,15 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
     assertEquals(0, notebookRepoSync.list(1, anonymous).size());
 
     /* create note */
-    Note note = notebookSync.createNote(anonymous);
+    Note note = notebook.createNote("test", "", anonymous);
 
     // check that automatically saved on both storages
     assertEquals(1, notebookRepoSync.list(0, anonymous).size());
     assertEquals(1, notebookRepoSync.list(1, anonymous).size());
-    assertEquals(notebookRepoSync.list(0, anonymous).get(0).getId(),notebookRepoSync.list(1, anonymous).get(0).getId());
+    assertEquals(notebookRepoSync.list(0, anonymous).get(0).getId(), notebookRepoSync.list(1, anonymous).get(0).getId());
 
-    notebookSync.removeNote(notebookRepoSync.list(0, null).get(0).getId(), anonymous);
+    NoteInfo noteInfo = notebookRepoSync.list(0, null).get(0);
+    notebook.removeNote(notebookRepoSync.get(noteInfo.getId(), note.getPath(), anonymous), anonymous);
   }
 
   @Test
@@ -149,15 +145,16 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
     assertEquals(0, notebookRepoSync.list(0, anonymous).size());
     assertEquals(0, notebookRepoSync.list(1, anonymous).size());
 
-    Note note = notebookSync.createNote(anonymous);
+    Note note = notebook.createNote("test", "", anonymous);
 
     /* check that created in both storage systems */
     assertEquals(1, notebookRepoSync.list(0, anonymous).size());
     assertEquals(1, notebookRepoSync.list(1, anonymous).size());
-    assertEquals(notebookRepoSync.list(0, anonymous).get(0).getId(),notebookRepoSync.list(1, anonymous).get(0).getId());
+    assertEquals(notebookRepoSync.list(0, anonymous).get(0).getId(), notebookRepoSync.list(1, anonymous).get(0).getId());
 
     /* remove Note */
-    notebookSync.removeNote(notebookRepoSync.list(0, anonymous).get(0).getId(), anonymous);
+    NoteInfo noteInfo = notebookRepoSync.list(0, null).get(0);
+    notebook.removeNote(notebookRepoSync.get(noteInfo.getId(), noteInfo.getPath(), anonymous), anonymous);
 
     /* check that deleted in both storages */
     assertEquals(0, notebookRepoSync.list(0, anonymous).size());
@@ -169,7 +166,8 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
   public void testSyncUpdateMain() throws IOException {
 
     /* create note */
-    Note note = notebookSync.createNote(anonymous);
+    Note note = notebook.createNote("/test", "test", anonymous);
+    note.setInterpreterFactory(mock(InterpreterFactory.class));
     Paragraph p1 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
     Map config = p1.getConfig();
     config.put("enabled", true);
@@ -181,41 +179,50 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
 
     /* new paragraph not yet saved into storages */
     assertEquals(0, notebookRepoSync.get(0,
-        notebookRepoSync.list(0, anonymous).get(0).getId(), anonymous).getParagraphs().size());
+        notebookRepoSync.list(0, anonymous).get(0).getId(),
+        notebookRepoSync.list(0, anonymous).get(0).getPath(), anonymous).getParagraphs().size());
     assertEquals(0, notebookRepoSync.get(1,
-        notebookRepoSync.list(1, anonymous).get(0).getId(), anonymous).getParagraphs().size());
+        notebookRepoSync.list(1, anonymous).get(0).getId(),
+        notebookRepoSync.list(1, anonymous).get(0).getPath(), anonymous).getParagraphs().size());
 
     /* save to storage under index 0 (first storage) */
     notebookRepoSync.save(0, note, anonymous);
 
     /* check paragraph saved to first storage */
     assertEquals(1, notebookRepoSync.get(0,
-        notebookRepoSync.list(0, anonymous).get(0).getId(), anonymous).getParagraphs().size());
+        notebookRepoSync.list(0, anonymous).get(0).getId(),
+        notebookRepoSync.list(0, anonymous).get(0).getPath(),
+        anonymous).getParagraphs().size());
     /* check paragraph isn't saved to second storage */
     assertEquals(0, notebookRepoSync.get(1,
-        notebookRepoSync.list(1, anonymous).get(0).getId(), anonymous).getParagraphs().size());
+        notebookRepoSync.list(1, anonymous).get(0).getId(),
+        notebookRepoSync.list(0, anonymous).get(0).getPath(),
+        anonymous).getParagraphs().size());
     /* apply sync */
     notebookRepoSync.sync(null);
     /* check whether added to second storage */
     assertEquals(1, notebookRepoSync.get(1,
-    notebookRepoSync.list(1, anonymous).get(0).getId(), anonymous).getParagraphs().size());
+        notebookRepoSync.list(1, anonymous).get(0).getId(),
+        notebookRepoSync.list(1, anonymous).get(0).getPath(), anonymous).getParagraphs().size());
     /* check whether same paragraph id */
     assertEquals(p1.getId(), notebookRepoSync.get(0,
-        notebookRepoSync.list(0, anonymous).get(0).getId(), anonymous).getLastParagraph().getId());
+        notebookRepoSync.list(0, anonymous).get(0).getId(),
+        notebookRepoSync.list(0, anonymous).get(0).getPath(), anonymous).getLastParagraph().getId());
     assertEquals(p1.getId(), notebookRepoSync.get(1,
-        notebookRepoSync.list(1, anonymous).get(0).getId(), anonymous).getLastParagraph().getId());
-    notebookRepoSync.remove(note.getId(), anonymous);
+        notebookRepoSync.list(1, anonymous).get(0).getId(),
+        notebookRepoSync.list(1, anonymous).get(0).getPath(), anonymous).getLastParagraph().getId());
+    notebookRepoSync.remove(note.getId(), note.getPath(), anonymous);
   }
 
   @Test
-  public void testSyncOnReloadedList() throws IOException {
+  public void testSyncOnReloadedList() throws Exception {
     /* check that both storage repos are empty */
     assertTrue(notebookRepoSync.getRepoCount() > 1);
     assertEquals(0, notebookRepoSync.list(0, anonymous).size());
     assertEquals(0, notebookRepoSync.list(1, anonymous).size());
 
-    File srcDir = new File("src/test/resources/2A94M5J1Z");
-    File destDir = new File(secNotebookDir + "/2A94M5J1Z");
+    File srcDir = new File("src/test/resources/notebook");
+    File destDir = secNotebookDir;
 
     /* copy manually new notebook into secondary storage repo and check repos */
     try {
@@ -223,13 +230,14 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
     } catch (IOException e) {
       LOG.error(e.toString(), e);
     }
+
     assertEquals(0, notebookRepoSync.list(0, anonymous).size());
-    assertEquals(1, notebookRepoSync.list(1, anonymous).size());
+    assertEquals(2, notebookRepoSync.list(1, anonymous).size());
 
     // After reloading notebooks repos should be synchronized
-    notebookSync.reloadAllNotes(anonymous);
-    assertEquals(1, notebookRepoSync.list(0, anonymous).size());
-    assertEquals(1, notebookRepoSync.list(1, anonymous).size());
+    notebook.reloadAllNotes(anonymous);
+    assertEquals(2, notebookRepoSync.list(0, anonymous).size());
+    assertEquals(2, notebookRepoSync.list(1, anonymous).size());
   }
 
   @Test
@@ -238,32 +246,31 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
     System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_ONE_WAY_SYNC.getVarName(), "true");
     conf = ZeppelinConfiguration.create();
     notebookRepoSync = new NotebookRepoSync(conf);
-    notebookSync = new Notebook(conf, notebookRepoSync, schedulerFactory, factory, interpreterSettingManager, this, search,
-            notebookAuthorization, credentials);
+    notebook = new Notebook(conf, mock(AuthorizationService.class), notebookRepoSync, new NoteManager(notebookRepoSync), factory, interpreterSettingManager, search, credentials, null);
 
     // check that both storage repos are empty
     assertTrue(notebookRepoSync.getRepoCount() > 1);
     assertEquals(0, notebookRepoSync.list(0, null).size());
     assertEquals(0, notebookRepoSync.list(1, null).size());
 
-    File srcDir = new File("src/test/resources/2A94M5J1Z");
-    File destDir = new File(secNotebookDir + "/2A94M5J1Z");
+    File srcDir = new File("src/test/resources/notebook");
+    File destDir = secNotebookDir;
 
-    // copy manually new notebook into secondary storage repo and check repos
+    /* copy manually new notebook into secondary storage repo and check repos */
     try {
       FileUtils.copyDirectory(srcDir, destDir);
     } catch (IOException e) {
       LOG.error(e.toString(), e);
     }
     assertEquals(0, notebookRepoSync.list(0, null).size());
-    assertEquals(1, notebookRepoSync.list(1, null).size());
+    assertEquals(2, notebookRepoSync.list(1, null).size());
 
     // after reloading the notebook should be wiped from secondary storage
-    notebookSync.reloadAllNotes(null);
+    notebook.reloadAllNotes(null);
     assertEquals(0, notebookRepoSync.list(0, null).size());
     assertEquals(0, notebookRepoSync.list(1, null).size());
 
-    destDir = new File(mainNotebookDir + "/2A94M5J1Z");
+    destDir = mainNotebookDir;
 
     // copy manually new notebook into primary storage repo and check repos
     try {
@@ -271,13 +278,13 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
     } catch (IOException e) {
       LOG.error(e.toString(), e);
     }
-    assertEquals(1, notebookRepoSync.list(0, null).size());
+    assertEquals(2, notebookRepoSync.list(0, null).size());
     assertEquals(0, notebookRepoSync.list(1, null).size());
 
     // after reloading notebooks repos should be synchronized
-    notebookSync.reloadAllNotes(null);
-    assertEquals(1, notebookRepoSync.list(0, null).size());
-    assertEquals(1, notebookRepoSync.list(1, null).size());
+    notebook.reloadAllNotes(null);
+    assertEquals(2, notebookRepoSync.list(0, null).size());
+    assertEquals(2, notebookRepoSync.list(1, null).size());
   }
 
   @Test
@@ -286,8 +293,7 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
     ZeppelinConfiguration vConf = ZeppelinConfiguration.create();
 
     NotebookRepoSync vRepoSync = new NotebookRepoSync(vConf);
-    Notebook vNotebookSync = new Notebook(vConf, vRepoSync, schedulerFactory, factory, interpreterSettingManager, this, search,
-            notebookAuthorization, credentials);
+    Notebook vNotebookSync = new Notebook(vConf, mock(AuthorizationService.class), vRepoSync, new NoteManager(vRepoSync), factory, interpreterSettingManager, search, credentials, null);
 
     // one git versioned storage initialized
     assertThat(vRepoSync.getRepoCount()).isEqualTo(1);
@@ -298,15 +304,18 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
     // no notes
     assertThat(vRepoSync.list(anonymous).size()).isEqualTo(0);
     // create note
-    Note note = vNotebookSync.createNote(anonymous);
+    Note note = vNotebookSync.createNote("/test", "test", anonymous);
     assertThat(vRepoSync.list(anonymous).size()).isEqualTo(1);
 
-    String noteId = vRepoSync.list(anonymous).get(0).getId();
+    NoteInfo noteInfo = vRepoSync.list(anonymous).values().iterator().next();
+    String noteId = noteInfo.getId();
+    String notePath = noteInfo.getPath();
     // first checkpoint
-    vRepoSync.checkpoint(noteId, "checkpoint message", anonymous);
-    int vCount = gitRepo.revisionHistory(noteId, anonymous).size();
+    vRepoSync.checkpoint(noteId, notePath, "checkpoint message", anonymous);
+    int vCount = gitRepo.revisionHistory(noteId, notePath, anonymous).size();
     assertThat(vCount).isEqualTo(1);
 
+    note.setInterpreterFactory(mock(InterpreterFactory.class));
     Paragraph p = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
     Map<String, Object> config = p.getConfig();
     config.put("enabled", true);
@@ -315,16 +324,16 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
 
     // save and checkpoint again
     vRepoSync.save(note, anonymous);
-    vRepoSync.checkpoint(noteId, "checkpoint message 2", anonymous);
-    assertThat(gitRepo.revisionHistory(noteId, anonymous).size()).isEqualTo(vCount + 1);
-    notebookRepoSync.remove(note.getId(), anonymous);
+    vRepoSync.checkpoint(noteId, notePath, "checkpoint message 2", anonymous);
+    assertThat(gitRepo.revisionHistory(noteId, notePath, anonymous).size()).isEqualTo(vCount + 1);
+    notebookRepoSync.remove(note.getId(), note.getPath(), anonymous);
   }
 
   @Test
   public void testSyncWithAcl() throws IOException {
     /* scenario 1 - note exists with acl on main storage */
     AuthenticationInfo user1 = new AuthenticationInfo("user1");
-    Note note = notebookSync.createNote(user1);
+    Note note = notebook.createNote("/test", "test", user1);
     assertEquals(0, note.getParagraphs().size());
 
     // saved on both storages
@@ -332,16 +341,16 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
     assertEquals(1, notebookRepoSync.list(1, null).size());
 
     /* check that user1 is the only owner */
-    NotebookAuthorization authInfo = NotebookAuthorization.getInstance();
     Set<String> entity = new HashSet<String>();
     entity.add(user1.getUser());
-    assertEquals(true, authInfo.isOwner(note.getId(), entity));
-    assertEquals(1, authInfo.getOwners(note.getId()).size());
-    assertEquals(0, authInfo.getReaders(note.getId()).size());
-    assertEquals(0, authInfo.getRunners(note.getId()).size());
-    assertEquals(0, authInfo.getWriters(note.getId()).size());
+    assertEquals(true, authorizationService.isOwner(note.getId(), entity));
+    assertEquals(1, authorizationService.getOwners(note.getId()).size());
+    assertEquals(0, authorizationService.getReaders(note.getId()).size());
+    assertEquals(0, authorizationService.getRunners(note.getId()).size());
+    assertEquals(0, authorizationService.getWriters(note.getId()).size());
 
     /* update note and save on secondary storage */
+    note.setInterpreterFactory(mock(InterpreterFactory.class));
     Paragraph p1 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
     p1.setText("hello world");
     assertEquals(1, note.getParagraphs().size());
@@ -349,92 +358,53 @@ public class NotebookRepoSyncTest implements JobListenerFactory {
 
     /* check paragraph isn't saved into first storage */
     assertEquals(0, notebookRepoSync.get(0,
-        notebookRepoSync.list(0, null).get(0).getId(), null).getParagraphs().size());
+        notebookRepoSync.list(0, null).get(0).getId(),
+        notebookRepoSync.list(0, null).get(0).getPath(), null).getParagraphs().size());
     /* check paragraph is saved into second storage */
     assertEquals(1, notebookRepoSync.get(1,
-        notebookRepoSync.list(1, null).get(0).getId(), null).getParagraphs().size());
+        notebookRepoSync.list(1, null).get(0).getId(),
+        notebookRepoSync.list(1, null).get(0).getPath(), null).getParagraphs().size());
 
     /* now sync by user1 */
     notebookRepoSync.sync(user1);
 
     /* check that note updated and acl are same on main storage*/
     assertEquals(1, notebookRepoSync.get(0,
-        notebookRepoSync.list(0, null).get(0).getId(), null).getParagraphs().size());
-    assertEquals(true, authInfo.isOwner(note.getId(), entity));
-    assertEquals(1, authInfo.getOwners(note.getId()).size());
-    assertEquals(0, authInfo.getReaders(note.getId()).size());
-    assertEquals(0, authInfo.getRunners(note.getId()).size());
-    assertEquals(0, authInfo.getWriters(note.getId()).size());
+        notebookRepoSync.list(0, null).get(0).getId(),
+        notebookRepoSync.list(0, null).get(0).getPath(), null).getParagraphs().size());
+    assertEquals(true, authorizationService.isOwner(note.getId(), entity));
+    assertEquals(1, authorizationService.getOwners(note.getId()).size());
+    assertEquals(0, authorizationService.getReaders(note.getId()).size());
+    assertEquals(0, authorizationService.getRunners(note.getId()).size());
+    assertEquals(0, authorizationService.getWriters(note.getId()).size());
 
     /* scenario 2 - note doesn't exist on main storage */
     /* remove from main storage */
-    notebookRepoSync.remove(0, note.getId(), user1);
+    notebookRepoSync.remove(0, note.getId(), note.getPath(), user1);
     assertEquals(0, notebookRepoSync.list(0, null).size());
     assertEquals(1, notebookRepoSync.list(1, null).size());
-    authInfo.removeNote(note.getId());
-    assertEquals(0, authInfo.getOwners(note.getId()).size());
-    assertEquals(0, authInfo.getReaders(note.getId()).size());
-    assertEquals(0, authInfo.getRunners(note.getId()).size());
-    assertEquals(0, authInfo.getWriters(note.getId()).size());
 
     /* now sync - should bring note from secondary storage with added acl */
     notebookRepoSync.sync(user1);
     assertEquals(1, notebookRepoSync.list(0, null).size());
     assertEquals(1, notebookRepoSync.list(1, null).size());
-    assertEquals(1, authInfo.getOwners(note.getId()).size());
-    assertEquals(1, authInfo.getReaders(note.getId()).size());
-    assertEquals(1, authInfo.getRunners(note.getId()).size());
-    assertEquals(1, authInfo.getWriters(note.getId()).size());
-    assertEquals(true, authInfo.isOwner(note.getId(), entity));
-    assertEquals(true, authInfo.isReader(note.getId(), entity));
-    assertEquals(true, authInfo.isRunner(note.getId(), entity));
-    assertEquals(true, authInfo.isWriter(note.getId(), entity));
+    assertEquals(1, authorizationService.getOwners(note.getId()).size());
+    assertEquals(0, authorizationService.getReaders(note.getId()).size());
+    assertEquals(0, authorizationService.getRunners(note.getId()).size());
+    assertEquals(0, authorizationService.getWriters(note.getId()).size());
   }
 
-  static void delete(File file){
-    if(file.isFile()) file.delete();
-      else if(file.isDirectory()){
-        File [] files = file.listFiles();
-        if(files!=null && files.length>0){
-          for(File f : files){
-            delete(f);
-          }
+  static void delete(File file) {
+    if (file.isFile()) {
+      file.delete();
+    } else if (file.isDirectory()) {
+      File[] files = file.listFiles();
+      if (files != null && files.length > 0) {
+        for (File f : files) {
+          delete(f);
         }
-        file.delete();
       }
+      file.delete();
+    }
   }
-
-  @Override
-  public ParagraphJobListener getParagraphJobListener(Note note) {
-    return new ParagraphJobListener(){
-
-      @Override
-      public void onOutputAppend(Paragraph paragraph, int idx, String output) {
-
-      }
-
-      @Override
-      public void onOutputUpdate(Paragraph paragraph, int idx, InterpreterResultMessage msg) {
-
-      }
-
-      @Override
-      public void onOutputUpdateAll(Paragraph paragraph, List<InterpreterResultMessage> msgs) {
-
-      }
-
-      @Override
-      public void onProgressUpdate(Job job, int progress) {
-      }
-
-      @Override
-      public void beforeStatusChange(Job job, Status before, Status after) {
-      }
-
-      @Override
-      public void afterStatusChange(Job job, Status before, Status after) {
-      }
-    };
-  }
-
 }
